@@ -33,25 +33,51 @@ foreach ($drops as $each_drop) {
 }
 unset($drops, $each_drop);
 
+/*
+ * Black list of all scripts to which front-end must submit data.
+ * Such scripts must not be loaded on home page.
+ *
+ */
+ $target_blacklist = array (
+    'import.php', 'export.php'
+    );
+
 // If we have a valid target, let's load that script instead
 if (! empty($_REQUEST['target'])
     && is_string($_REQUEST['target'])
     && ! preg_match('/^index/', $_REQUEST['target'])
+    && ! in_array($_REQUEST['target'], $target_blacklist)
     && in_array($_REQUEST['target'], $goto_whitelist)
 ) {
     include $_REQUEST['target'];
     exit;
 }
 
+if (isset($_REQUEST['ajax_request']) && ! empty($_REQUEST['access_time'])) {
+    exit;
+}
+
+// See FAQ 1.34
+if (! empty($_REQUEST['db'])) {
+    $page = null;
+    if (! empty($_REQUEST['table'])) {
+        $page = $GLOBALS['cfg']['DefaultTabTable'];
+    } else {
+        $page = $GLOBALS['cfg']['DefaultTabDatabase'];
+    }
+    include $page;
+    exit;
+}
+
 /**
  * Check if it is an ajax request to reload the recent tables list.
  */
-require_once 'libraries/RecentTable.class.php';
+require_once 'libraries/RecentFavoriteTable.class.php';
 if ($GLOBALS['is_ajax_request'] && ! empty($_REQUEST['recent_table'])) {
     $response = PMA_Response::getInstance();
     $response->addJSON(
-        'options',
-        PMA_RecentTable::getInstance()->getHtmlSelectOption()
+        'list',
+        PMA_RecentFavoriteTable::getInstance('recent')->getHtmlList()
     );
     exit;
 }
@@ -75,7 +101,8 @@ if (! empty($message)) {
     unset($message);
 }
 
-$common_url_query =  PMA_URL_getCommon('', '');
+$common_url_query =  PMA_URL_getCommon();
+$mysql_cur_user_and_host = '';
 
 // when $server > 0, a server has been chosen so we can display
 // all MySQL-related information
@@ -107,6 +134,8 @@ if ($server > 0) {
 }
 
 echo '<div id="maincontainer">' . "\n";
+// Anchor for favorite tables synchronization.
+echo PMA_RecentFavoriteTable::getInstance('favorite')->getHtmlSyncFavoriteTables();
 echo '<div id="main_pane_left">';
 if ($server > 0 || count($cfg['Servers']) > 1
 ) {
@@ -156,7 +185,7 @@ if ($server > 0 || count($cfg['Servers']) > 1
                 PMA_printListItem(
                     PMA_Util::getImage('s_passwd.png') . " " . __('Change password'),
                     'li_change_password',
-                    'user_password.php?' . $common_url_query,
+                    'user_password.php' . $common_url_query,
                     null,
                     null,
                     'change_password_anchor',
@@ -169,7 +198,7 @@ if ($server > 0 || count($cfg['Servers']) > 1
         echo '        <form method="post" action="index.php">' . "\n"
            . PMA_URL_getHiddenInputs(null, null, 4, 'collation_connection')
            . '            <label for="select_collation_connection">' . "\n"
-           . '                '. PMA_Util::getImage('s_asci.png') . " "
+           . '                ' . PMA_Util::getImage('s_asci.png') . " "
                                . __('Server connection collation') . "\n"
            // put the doc link in the form so that it appears on the same line
            . PMA_Util::showMySQLDocu('Charset-connection')
@@ -182,7 +211,6 @@ if ($server > 0 || count($cfg['Servers']) > 1
                'select_collation_connection',
                $collation_connection,
                true,
-               4,
                true
            )
            . '        </form>' . "\n"
@@ -223,9 +251,9 @@ echo '</ul>';
 if ($server > 0) {
     echo '<ul>';
     PMA_printListItem(
-        PMA_Util::getImage('b_tblops.png')." " .__('More settings'),
+        PMA_Util::getImage('b_tblops.png') . " " . __('More settings'),
         'li_user_preferences',
-        'prefs_manage.php?' . $common_url_query,
+        'prefs_manage.php' . $common_url_query,
         null,
         null,
         null,
@@ -273,7 +301,8 @@ if ($server > 0 && $GLOBALS['cfg']['ShowServerInfo']) {
     echo '        ' . __('Server charset:') . ' '
        . '        <span lang="en" dir="ltr">';
     if (! PMA_DRIZZLE) {
-        echo '           ' . $mysql_charsets_descriptions[$mysql_charset_map['utf-8']];
+        echo '           '
+            . $mysql_charsets_descriptions[$mysql_charset_map['utf-8']];
     }
     echo '           (' . $mysql_charset_map['utf-8'] . ')'
        . '        </span>'
@@ -291,12 +320,7 @@ if ($GLOBALS['cfg']['ShowServerInfo'] || $GLOBALS['cfg']['ShowPhpInfo']) {
 
         if ($server > 0) {
             $client_version_str = $GLOBALS['dbi']->getClientInfo();
-            if (preg_match('#\d+\.\d+\.\d+#', $client_version_str)
-                && in_array(
-                    $GLOBALS['cfg']['Server']['extension'],
-                    array('mysql', 'mysqli')
-                )
-            ) {
+            if (preg_match('#\d+\.\d+\.\d+#', $client_version_str)) {
                 $client_version_str = 'libmysql - ' . $client_version_str;
             }
             PMA_printListItem(
@@ -304,11 +328,15 @@ if ($GLOBALS['cfg']['ShowServerInfo'] || $GLOBALS['cfg']['ShowPhpInfo']) {
                 'li_mysql_client_version'
             );
 
-            $php_ext_string = __('PHP extension:') . ' '
-                . $GLOBALS['cfg']['Server']['extension'] . ' '
-                . PMA_Util::showPHPDocu(
-                    'book.' . $GLOBALS['cfg']['Server']['extension'] . '.php'
-                );
+            $php_ext_string = __('PHP extension:') . ' ';
+            if (PMA_DatabaseInterface::checkDbExtension('mysqli')) {
+                $extension = 'mysqli';
+            } else {
+                $extension = 'mysql';
+            }
+            $php_ext_string  .= $extension . ' '
+                . PMA_Util::showPHPDocu('book.' . $extension . '.php');
+
             PMA_printListItem(
                 $php_ext_string,
                 'li_used_php_extension'
@@ -320,7 +348,7 @@ if ($GLOBALS['cfg']['ShowServerInfo'] || $GLOBALS['cfg']['ShowPhpInfo']) {
         PMA_printListItem(
             __('Show PHP information'),
             'li_phpinfo',
-            'phpinfo.php?' . $common_url_query,
+            'phpinfo.php' . $common_url_query,
             null,
             '_blank'
         );
@@ -341,7 +369,7 @@ if ($GLOBALS['cfg']['VersionCheck']
     $class = 'jsversioncheck';
 }
 PMA_printListItem(
-    __('Version information:') . ' ' . PMA_VERSION,
+    __('Version information:') . ' <span class="version">' . PMA_VERSION . '</span>',
     'li_pma_version',
     null,
     null,
@@ -389,7 +417,7 @@ PMA_printListItem(
 PMA_printListItem(
     __('List of changes'),
     'li_pma_changes',
-    PMA_linkURL('changelog.php'),
+    'changelog.php' . PMA_URL_getCommon(),
     null,
     '_blank'
 );
@@ -476,7 +504,7 @@ if ($GLOBALS['cfg']['LoginCookieStore'] != 0
 /**
  * Check if user does not have defined blowfish secret and it is being used.
  */
-if (! empty($_SESSION['auto_blowfish_secret'])
+if (! empty($_SESSION['encryption_key'])
     && empty($GLOBALS['cfg']['blowfish_secret'])
 ) {
     trigger_error(
@@ -501,9 +529,21 @@ if ($server > 0) {
     if (! $cfgRelation['allworks']
         && $cfg['PmaNoRelation_DisableWarning'] == false
     ) {
-        $msg = PMA_Message::notice(__('The phpMyAdmin configuration storage is not completely configured, some extended features have been deactivated. To find out why click %shere%s.'));
+        $msg_text = __(
+            'The phpMyAdmin configuration storage is not completely '
+            . 'configured, some extended features have been deactivated. '
+            . '%sFind out why%s. '
+        );
+        if ($cfg['ZeroConf'] == true) {
+            $msg_text .= '<br>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;' .
+                __(
+                    'Or alternately go to \'Operations\' tab of any database '
+                    . 'to set it up there.'
+                );
+        }
+        $msg = PMA_Message::notice($msg_text);
         $msg->addParam(
-            '<a href="' . $cfg['PmaAbsoluteUri'] . 'chk_rel.php?'
+            '<a href="' . $cfg['PmaAbsoluteUri'] . 'chk_rel.php'
             . $common_url_query . '">',
             false
         );
@@ -524,15 +564,23 @@ if ($server > 0) {
  * If no default server is set, $GLOBALS['dbi'] is not defined yet.
  * Drizzle can speak MySQL protocol, so don't warn about version mismatch for
  * Drizzle servers.
+ * We also do not warn if MariaDB is detected, as it has its own version
+ * numbering.
  */
 if (isset($GLOBALS['dbi'])
     && !PMA_DRIZZLE
     && $cfg['ServerLibraryDifference_DisableWarning'] == false
 ) {
+    /** @var PMA_String $pmaString */
+    $pmaString = $GLOBALS['PMA_String'];
+
     $_client_info = $GLOBALS['dbi']->getClientInfo();
     if ($server > 0
-        && strpos($_client_info, 'mysqlnd') === false
-        && substr(PMA_MYSQL_CLIENT_API, 0, 3) != substr(PMA_MYSQL_INT_VERSION, 0, 3)
+        && /*overload*/mb_strpos($_client_info, 'mysqlnd') === false
+        && /*overload*/mb_strpos(PMA_MYSQL_STR_VERSION, 'MariaDB') === false
+        && substr(PMA_MYSQL_CLIENT_API, 0, 3) != substr(
+            PMA_MYSQL_INT_VERSION, 0, 3
+        )
     ) {
         trigger_error(
             PMA_sanitize(
@@ -569,15 +617,6 @@ if ($cfg['SuhosinDisableWarning'] == false
     );
 }
 
-/**
- * Warning about mcrypt.
- */
-if (! function_exists('mcrypt_encrypt')
-    && ! $GLOBALS['cfg']['McryptDisableWarning']
-) {
-    PMA_warnMissingExtension('mcrypt');
-}
-
 /**
  * Warning about incomplete translations.
  *
@@ -606,7 +645,7 @@ if (file_exists('libraries/language_stats.inc.php')) {
  * prints list item for main page
  *
  * @param string $name            displayed text
- * @param string $id              id, used for css styles
+ * @param string $listId          id, used for css styles
  * @param string $url             make item as link with $url as target
  * @param string $mysql_help_page display a link to MySQL's manual
  * @param string $target          special target for $url
@@ -617,11 +656,11 @@ if (file_exists('libraries/language_stats.inc.php')) {
  *
  * @return void
  */
-function PMA_printListItem($name, $id = null, $url = null,
+function PMA_printListItem($name, $listId = null, $url = null,
     $mysql_help_page = null, $target = null, $a_id = null, $class = null,
     $a_class = null
 ) {
-    echo '<li id="' . $id . '"';
+    echo '<li id="' . $listId . '"';
     if (null !== $class) {
         echo ' class="' . $class . '"';
     }
@@ -632,10 +671,10 @@ function PMA_printListItem($name, $id = null, $url = null,
             echo ' target="' . $target . '"';
         }
         if (null != $a_id) {
-            echo ' id="' . $a_id .'"';
+            echo ' id="' . $a_id . '"';
         }
         if (null != $a_class) {
-            echo ' class="' . $a_class .'"';
+            echo ' class="' . $a_class . '"';
         }
         echo '>';
     }
