@@ -148,6 +148,9 @@ var PMA_console = {
             $('#pma_bookmarks .switch_button').click(function() {
                 PMA_console.hideCard($(this).closest('.card'));
             });
+            $('#pma_console_options .switch_button').click(function() {
+                PMA_console.hideCard($(this).closest('.card'));
+            });
 
             $('#pma_console_options input[type=checkbox]').change(function() {
                 PMA_console.updateConfig();
@@ -281,10 +284,10 @@ var PMA_console = {
         PMA_console.$consoleContent.animate({'margin-bottom': 0},
             'fast', 'easeOutQuart', function() {
                 $(window).trigger('resize');
+                if(inputFocus) {
+                    PMA_consoleInput.focus();
+                }
             });
-        if(inputFocus) {
-            PMA_consoleInput.focus();
-        }
     },
     /**
      * Change console to SQL information mode
