@@ -18,15 +18,21 @@ header('Expires: ' . gmdate('D, d M Y H:i:s', time() + 3600) . ' GMT');
 // Avoid loading the full common.inc.php because this would add many
 // non-js-compatible stuff like DOCTYPE
 define('PMA_MINIMUM_COMMON', true);
+define('PMA_PATH_TO_BASEDIR', '../');
 require_once './libraries/common.inc.php';
 // Close session early as we won't write anything there
 session_write_close();
 // But this one is needed for PMA_escapeJsString()
 require_once './libraries/js_escape.lib.php';
+require_once './libraries/Util.class.php';
 
-$js_messages['strNoDropDatabases'] = $cfg['AllowUserDropDatabase'] ? '' : __('"DROP DATABASE" statements are disabled.');
+$js_messages['strNoDropDatabases'] = __('"DROP DATABASE" statements are disabled.');
+if ($cfg['AllowUserDropDatabase']) {
+    $js_messages['strNoDropDatabases'] = '';
+}
 
 /* For confirmations */
+$js_messages['strConfirm'] = __('Confirm');
 $js_messages['strDoYouReally'] = __('Do you really want to execute "%s"?');
 $js_messages['strDropDatabaseStrongWarning'] = __('You are about to DESTROY a complete database!');
 $js_messages['strDropTableStrongWarning'] = __('You are about to DESTROY a complete table!');
@@ -34,14 +40,42 @@ $js_messages['strTruncateTableStrongWarning'] = __('You are about to TRUNCATE a
 $js_messages['strDeleteTrackingData'] = __('Delete tracking data for this table');
 $js_messages['strDeletingTrackingData'] = __('Deleting tracking data');
 $js_messages['strDroppingPrimaryKeyIndex'] = __('Dropping Primary Key/Index');
+$js_messages['strDroppingForeignKey'] = __('Dropping Foreign key.');
 $js_messages['strOperationTakesLongTime'] = __('This operation could take a long time. Proceed anyway?');
+$js_messages['strDropUserGroupWarning'] = __('Do you really want to delete user group "%s"?');
+$js_messages['strConfirmDeleteQBESearch'] = __('Do you really want to delete the search "%s"?');
+$js_messages['strConfirmNavigation'] = __('You have unsaved changes; are you sure you want to leave this page?');
+$js_messages['strDropUserWarning'] = __('Do you really want to revoke the selected user(s) ?');
+$js_messages['strDeleteCentralColumnWarning'] = __('Do you really want to delete this central column?');
+
+/* For modal dialog buttons */
+$js_messages['strSaveAndClose'] = __('Save & Close');
+$js_messages['strReset'] = __('Reset');
+$js_messages['strResetAll'] = __('Reset All');
 
 /* For indexes */
 $js_messages['strFormEmpty'] = __('Missing value in the form!');
-$js_messages['strNotNumber'] = __('This is not a number!');
+$js_messages['strRadioUnchecked'] = __('Select at least one of the options!');
+$js_messages['strEnterValidNumber'] = __('Please enter a valid number!');
+$js_messages['strEnterValidLength'] = __('Please enter a valid length!');
 $js_messages['strAddIndex'] = __('Add Index');
 $js_messages['strEditIndex'] = __('Edit Index');
 $js_messages['strAddToIndex'] = __('Add %s column(s) to index');
+$js_messages['strCreateSingleColumnIndex'] = __('Create single-column index');
+$js_messages['strCreateCompositeIndex'] = __('Create composite index');
+$js_messages['strCompositeWith'] = __('Composite with:');
+$js_messages['strMissingColumn'] = __('Please select column(s) for the index.');
+
+/* For Create Table */
+$js_messages['strLeastColumnError'] = __('You have to add at least one column.');
+
+/* For Preview SQL*/
+$js_messages['strPreviewSQL'] = __('Preview SQL');
+
+/* For Simulate DML*/
+$js_messages['strSimulateDML'] = __('Simulate query');
+$js_messages['strMatchedRows'] = __('Matched rows:');
+$js_messages['strSQLQuery'] = __('SQL query:');
 
 /* Charts */
 /* l10n: Default label for the y-Axis of Charts */
@@ -52,20 +86,9 @@ $js_messages['strHostEmpty'] = __('The host name is empty!');
 $js_messages['strUserEmpty'] = __('The user name is empty!');
 $js_messages['strPasswordEmpty'] = __('The password is empty!');
 $js_messages['strPasswordNotSame'] = __('The passwords aren\'t the same!');
-$js_messages['strAddUser'] = __('Add user');
-$js_messages['strReloadingPrivileges'] = __('Reloading Privileges');
 $js_messages['strRemovingSelectedUsers'] = __('Removing Selected Users');
 $js_messages['strClose'] = __('Close');
 
-/* for server_status.js */
-$js_messages['strEdit'] = __('Edit');
-$js_messages['strLiveTrafficChart'] = __('Live traffic chart');
-$js_messages['strLiveConnChart'] = __('Live conn./process chart');
-$js_messages['strLiveQueryChart'] = __('Live query chart');
-
-$js_messages['strStaticData'] = __('Static data');
-/* l10n: Total number of queries */
-$js_messages['strTotal'] = __('Total');
 /* l10n: Other, small valued, queries */
 $js_messages['strOther'] = __('Other');
 /* l10n: Thousands separator */
@@ -76,7 +99,7 @@ $js_messages['strDecimalSeparator'] = __('.');
 $js_messages['strChartConnectionsTitle'] = __('Connections / Processes');
 
 /* server status monitor */
-$js_messages['strIncompatibleMonitorConfig'] = __('Local monitor configuration incompatible');
+$js_messages['strIncompatibleMonitorConfig'] = __('Local monitor configuration incompatible!');
 $js_messages['strIncompatibleMonitorConfigDescription'] = __('The chart arrangement configuration in your browsers local storage is not compatible anymore to the newer version of the monitor dialog. It is very likely that your current configuration will not work anymore. Please reset your configuration to default in the <i>Settings</i> menu.');
 
 $js_messages['strQueryCacheEfficiency'] = __('Query cache efficiency');
@@ -118,14 +141,14 @@ $js_messages['strTables'] = __('%d table(s)');
 $js_messages['strQuestions'] = __('Questions');
 $js_messages['strTraffic'] = __('Traffic');
 $js_messages['strSettings'] = __('Settings');
-$js_messages['strRemoveChart'] = __('Remove chart');
-$js_messages['strEditChart'] = __('Edit title and labels');
 $js_messages['strAddChart'] = __('Add chart to grid');
 $js_messages['strClose'] = __('Close');
-$js_messages['strAddOneSeriesWarning'] = __('Please add at least one variable to the series');
+$js_messages['strAddOneSeriesWarning'] = __('Please add at least one variable to the series!');
 $js_messages['strNone'] = __('None');
 $js_messages['strResumeMonitor'] = __('Resume monitor');
 $js_messages['strPauseMonitor'] = __('Pause monitor');
+$js_messages['strStartRefresh'] = __('Start auto refresh');
+$js_messages['strStopRefresh'] = __('Stop auto refresh');
 /* Monitor: Instructions Dialog */
 $js_messages['strBothLogOn'] = __('general_log and slow_query_log are enabled.');
 $js_messages['strGenLogOn'] = __('general_log is enabled.');
@@ -143,8 +166,11 @@ $js_messages['strEnableVar'] = __('Enable %s');
 /* l10n: Disable in this context means setting a status variable to OFF */
 $js_messages['strDisableVar'] = __('Disable %s');
 /* l10n: %d seconds */
-$js_messages['setSetLongQueryTime'] = __('Set long_query_time to %ds');
-$js_messages['strNoSuperUser'] = __('You can\'t change these variables. Please log in as root or contact your database administrator.');
+$js_messages['setSetLongQueryTime'] = __('Set long_query_time to %d seconds.');
+$js_messages['strNoSuperUser'] = __(
+    'You can\'t change these variables. Please log in as root or contact'
+    . ' your database administrator.'
+);
 $js_messages['strChangeSettings'] = __('Change settings');
 $js_messages['strCurrentSettings'] = __('Current settings');
 
@@ -156,6 +182,9 @@ $js_messages['strUnit'] = __('Unit');
 
 $js_messages['strFromSlowLog'] = __('From slow log');
 $js_messages['strFromGeneralLog'] = __('From general log');
+$js_messages['strServerLogError'] = __(
+    'The database name is not known for this query in the server\'s logs.'
+);
 $js_messages['strAnalysingLogsTitle'] = __('Analysing logs');
 $js_messages['strAnalysingLogs'] = __('Analysing & loading logs. This may take a while.');
 $js_messages['strCancelRequest'] = __('Cancel request');
@@ -175,8 +204,6 @@ $js_messages['strTotalTime'] = __('Total time:');
 $js_messages['strProfilingResults'] = __('Profiling results');
 $js_messages['strTable'] = _pgettext('Display format', 'Table');
 $js_messages['strChart'] = __('Chart');
-$js_messages['strChartEdit'] = __('Edit chart');
-$js_messages['strSeries'] = __('Series');
 
 /* l10n: A collection of available filters */
 $js_messages['strFiltersForLogTable'] = __('Log table filter options');
@@ -194,11 +221,14 @@ $js_messages['strReloadPage'] = __('Reload page');
 
 $js_messages['strAffectedRows'] = __('Affected rows:');
 
-$js_messages['strFailedParsingConfig'] = __('Failed parsing config file. It doesn\'t seem to be valid JSON code.');
+$js_messages['strFailedParsingConfig'] = __(
+    'Failed parsing config file. It doesn\'t seem to be valid JSON code.'
+);
 $js_messages['strFailedBuildingGrid'] = __('Failed building chart grid with imported config. Resetting to default config…');
 $js_messages['strImport'] = __('Import');
 $js_messages['strImportDialogTitle'] = __('Import monitor configuration');
-$js_messages['strImportDialogMessage'] = __('Please select the file you want to import');
+$js_messages['strImportDialogMessage'] = __('Please select the file you want to import.');
+$js_messages['strNoImportFile'] = __('No files available on server for import!');
 
 $js_messages['strAnalyzeQuery'] = __('Analyse Query');
 
@@ -219,7 +249,8 @@ $js_messages['strGo'] = __('Go');
 $js_messages['strCancel'] = __('Cancel');
 
 /* For Ajax Notifications */
-$js_messages['strLoading'] = __('Loading');
+$js_messages['strLoading'] = __('Loading…');
+$js_messages['strAbortedRequest'] = __('Request Aborted!!');
 $js_messages['strProcessingRequest'] = __('Processing Request');
 $js_messages['strErrorProcessingRequest'] = __('Error in Processing Request');
 $js_messages['strErrorCode'] = __('Error code: %s');
@@ -232,20 +263,15 @@ $js_messages['strDismiss'] = __('Click to dismiss this notification');
 
 /* For db_operations.js */
 $js_messages['strRenamingDatabases'] = __('Renaming Databases');
-$js_messages['strReloadDatabase'] = __('Reload Database');
 $js_messages['strCopyingDatabase'] = __('Copying Database');
 $js_messages['strChangingCharset'] = __('Changing Charset');
-$js_messages['strTableMustHaveAtleastOneColumn'] = __('Table must have at least one column');
-$js_messages['strYes'] = __('Yes');
 $js_messages['strNo'] = __('No');
 
 /* For db_stucture.js */
-$js_messages['strInsertTable'] = __('Insert Table');
-$js_messages['strHideIndexes'] = __('Hide indexes');
-$js_messages['strShowIndexes'] = __('Show indexes');
 $js_messages['strForeignKeyCheck'] = __('Foreign key check:');
 $js_messages['strForeignKeyCheckEnabled'] = __('(Enabled)');
 $js_messages['strForeignKeyCheckDisabled'] = __('(Disabled)');
+$js_messages['strErrorRealRowCount'] = __('Failed to get real row count.');
 
 /* For db_search.js */
 $js_messages['strSearching'] = __('Searching');
@@ -261,20 +287,55 @@ $js_messages['MissingReturn'] = __('The definition of a stored function must con
 $js_messages['enum_editor'] = __('ENUM/SET editor');
 $js_messages['enum_columnVals'] =__('Values for column %s');
 $js_messages['enum_newColumnVals'] = __('Values for a new column');
-$js_messages['enum_hint'] =__('Enter each value in a separate field');
+$js_messages['enum_hint'] =__('Enter each value in a separate field.');
 $js_messages['enum_addValue'] =__('Add %d value(s)');
 
 /* For import.js */
-$js_messages['strImportCSV'] = __('Note: If the file contains multiple tables, they will be combined into one');
+$js_messages['strImportCSV'] = __('Note: If the file contains multiple tables, they will be combined into one.');
 
 /* For sql.js */
 $js_messages['strHideQueryBox'] = __('Hide query box');
 $js_messages['strShowQueryBox'] = __('Show query box');
 $js_messages['strEdit'] = __('Edit');
-$js_messages['strNoRowSelected'] = __('No rows selected');
-$js_messages['strChangeTbl'] = __('Change');
-$js_messages['strQueryExecutionTime'] = __('Query execution time');
 $js_messages['strNotValidRowNumber'] = __('%d is not valid row number.');
+$js_messages['strBrowseForeignValues'] = __('Browse foreign values');
+
+/* For Central list of columns */
+$js_messages['pickColumn'] = __('Pick');
+$js_messages['pickColumnTitle'] = __('Column selector');
+$js_messages['searchList'] = __('Search this list');
+$js_messages['strEmptyCentralList'] = __('No columns in the central list. Make sure the Central columns list for database %s has columns that are not present in the current table.');
+$js_messages['seeMore'] = __('See more');
+$js_messages['confirmTitle'] = __('Are you sure?');
+$js_messages['makeConsistentMessage'] = __('This action may change some of the columns definition.<br/>Are you sure you want to continue?');
+$js_messages['strContinue'] = __('Continue');
+
+/** For normalization */
+$js_messages['strAddPrimaryKey'] = __('Add primary key');
+$js_messages['strPrimaryKeyAdded'] = __('Primary key added.');
+$js_messages['strToNextStep'] = __('Taking you to next step…');
+$js_messages['strFinishMsg'] = __("The first step of normalization is complete for table '%s'.");
+$js_messages['strEndStep'] = __("End of step");
+$js_messages['str2NFNormalization'] = __('Second step of normalization (2NF)');
+$js_messages['strDone'] = __('Done');
+$js_messages['strConfirmPd'] = __('Confirm partial dependencies');
+$js_messages['strSelectedPd'] = __('Selected partial dependencies are as follows:');
+$js_messages['strPdHintNote'] = __('Note: a, b -> d,f implies values of columns a and b combined together can determine values of column d and column f.');
+$js_messages['strNoPdSelected'] = __('No partial dependencies selected!');
+$js_messages['strBack'] = __('Back');
+$js_messages['strShowPossiblePd'] = __('Show me the possible partial dependencies based on data in the table');
+$js_messages['strHidePd'] = __('Hide partial dependencies list');
+$js_messages['strWaitForPd'] = __('Sit tight! It may take few seconds depending on data size and column count of the table.');
+$js_messages['strStep'] = __('Step');
+$js_messages['strMoveRepeatingGroup'] = '<ol><b>' . __('The following actions will be performed:') . '</b>'
+    . '<li>' . __('DROP columns %s from the table %s') . '</li>'
+    . '<li>' . __('Create the following table') . '</li>';
+$js_messages['strNewTablePlaceholder'] = 'Enter new table name';
+$js_messages['strNewColumnPlaceholder'] = 'Enter column name';
+$js_messages['str3NFNormalization'] = __('Third step of normalization (3NF)');
+$js_messages['strConfirmTd'] = __('Confirm transitive dependencies');
+$js_messages['strSelectedTd'] = __('Selected dependencies are as follows:');
+$js_messages['strNoTdSelected'] = __('No dependencies selected!');
 
 /* For server_variables.js */
 $js_messages['strSave'] = __('Save');
@@ -282,9 +343,17 @@ $js_messages['strSave'] = __('Save');
 /* For tbl_select.js */
 $js_messages['strHideSearchCriteria'] = __('Hide search criteria');
 $js_messages['strShowSearchCriteria'] = __('Show search criteria');
+$js_messages['strRangeSearch'] = __('Range search');
+$js_messages['strColumnMax'] = __('Column maximum:');
+$js_messages['strColumnMin'] = __('Column minimum:');
+$js_messages['strMinValue'] = __('Minimum value:');
+$js_messages['strMaxValue'] = __('Maximum value:');
+
+/* For tbl_find_replace.js */
+$js_messages['strHideFindNReplaceCriteria'] = __('Hide find and replace criteria');
+$js_messages['strShowFindNReplaceCriteria'] = __('Show find and replace criteria');
 
 /* For tbl_zoom_plot_jqplot.js */
-$js_messages['strZoomSearch'] = __('Zoom Search');
 $js_messages['strDisplayHelp'] = '<ul><li>'
     . __('Each point represents a data row.')
     . '</li><li>'
@@ -299,8 +368,9 @@ $js_messages['strDisplayHelp'] = '<ul><li>'
     . __('The plot can be resized by dragging it along the bottom right corner.')
     . '</li></ul>';
 $js_messages['strInputNull'] = '<strong>' . __('Select two columns') . '</strong>';
-$js_messages['strSameInputs'] = '<strong>' . __('Select two different columns') . '</strong>';
-$js_messages['strQueryResults'] = __('Query results');
+$js_messages['strSameInputs'] = '<strong>'
+    . __('Select two different columns')
+    . '</strong>';
 $js_messages['strDataPointContent'] = __('Data point content');
 
 /* For tbl_change.js */
@@ -317,32 +387,60 @@ $js_messages['strInnerRing'] = __('Inner Ring');
 $js_messages['strOuterRing'] = __('Outer Ring');
 $js_messages['strAddPoint'] = __('Add a point');
 $js_messages['strAddInnerRing'] = __('Add an inner ring');
-$js_messages['strAddPolygon'] = __('Add a polygon');
-
-/* For tbl_structure.js */
-$js_messages['strAddColumns'] = __('Add columns');
+$js_messages['strFunctionHint'] = __('Shift + Click on function name to apply to all rows.');
+$js_messages['strYes'] = __('Yes');
+$js_messages['strCopyEncryptionKey'] = __('Do you want to copy encryption key?');
+$js_messages['strEncryptionKey'] = __('Encryption key');
 
 /* Designer (js/pmd/move.js) */
 $js_messages['strSelectReferencedKey'] = __('Select referenced key');
 $js_messages['strSelectForeignKey'] = __('Select Foreign Key');
-$js_messages['strPleaseSelectPrimaryOrUniqueKey'] = __('Please select the primary key or a unique key');
+$js_messages['strPleaseSelectPrimaryOrUniqueKey'] = __('Please select the primary key or a unique key!');
 $js_messages['strChangeDisplay'] = __('Choose column to display');
-$js_messages['strLeavingDesigner'] = __('You haven\'t saved the changes in the layout. They will be lost if you don\'t save them. Do you want to continue?');
+$js_messages['strLeavingDesigner'] = __(
+    'You haven\'t saved the changes in the layout. They will be lost if you'
+    . ' don\'t save them. Do you want to continue?'
+);
+$js_messages['strPageName'] = __('Page name');
+$js_messages['strSavePage'] = __('Save page');
+$js_messages['strOpenPage'] = __('Open page');
+$js_messages['strDeletePage'] = __('Delete page');
+$js_messages['strUntitled'] = __('Untitled');
+$js_messages['strSelectPage'] = __('Please select a page to continue');
+$js_messages['strEnterValidPageName'] = __('Please enter a valid page name');
+$js_messages['strLeavingPage'] = __('Do you want to save the changes to the current page?');
+$js_messages['strSuccessfulPageDelete'] = __('Successfully deleted the page');
+$js_messages['strExportRelationalSchema'] = __('Export relational schema');
+$js_messages['strModificationSaved'] = __('Modifications have been saved');
 
 /* Visual query builder (js/pmd/move.js) */
-$js_messages['strAddOption'] = __('Add an option for column ');
-$js_messages['strObjectsCreated'] = __('%d object(s) created');
+$js_messages['strAddOption'] = __('Add an option for column "%s".');
+$js_messages['strObjectsCreated'] = __('%d object(s) created.');
 
 /* For makegrid.js (column reordering, show/hide column, grid editing) */
-$js_messages['strCellEditHint'] = __('Press escape to cancel editing');
+$js_messages['strCellEditHint'] = __('Press escape to cancel editing.');
 $js_messages['strSaveCellWarning'] = __('You have edited some data and they have not been saved. Are you sure you want to leave this page before saving the data?');
-$js_messages['strColOrderHint'] = __('Drag to reorder');
-$js_messages['strSortHint'] = __('Click to sort');
-$js_messages['strColMarkHint'] = __('Click to mark/unmark');
-$js_messages['strColNameCopyHint'] = __('Double-click to copy column name');
-$js_messages['strColVisibHint'] = __('Click the drop-down arrow<br />to toggle column\'s visibility');
+$js_messages['strColOrderHint'] = __('Drag to reorder.');
+$js_messages['strSortHint'] = __('Click to sort results by this column.');
+$js_messages['strMultiSortHint'] = __('Shift+Click to add this column to ORDER BY clause or to toggle ASC/DESC.<br />- Ctrl+Click or Alt+Click (Mac: Shift+Option+Click) to remove column from ORDER BY clause');
+$js_messages['strColMarkHint'] = __('Click to mark/unmark.');
+$js_messages['strColNameCopyHint'] = __('Double-click to copy column name.');
+$js_messages['strColVisibHint'] = __(
+    'Click the drop-down arrow<br />to toggle column\'s visibility.'
+);
 $js_messages['strShowAllCol'] = __('Show all');
 $js_messages['strAlertNonUnique'] = __('This table does not contain a unique column. Features related to the grid edit, checkbox, Edit, Copy and Delete links may not work after saving.');
+$js_messages['strEnterValidHex'] = __('Please enter a valid hexadecimal string. Valid characters are 0-9, A-F.');
+$js_messages['strShowAllRowsWarning'] = __('Do you really want to see all of the rows? For a big table this could crash the browser.');
+
+/** Drag & Drop sql import messages */
+$js_messages['dropImportMessageCancel'] = __('cancel');
+$js_messages['dropImportMessageAborted'] = __('Aborted');
+$js_messages['dropImportMessageFailed'] = __('Failed');
+$js_messages['dropImportMessageSuccess'] = __('Success');
+$js_messages['dropImportImportResultHeader'] = __('Import status');
+$js_messages['dropImportDropFiles'] = __('Drop files here');
+$js_messages['dropImportSelectDB'] = __('Select database first');
 
 // this approach does not work when the parameter is changed via user prefs
 switch ($GLOBALS['cfg']['GridEditing']) {
@@ -355,10 +453,10 @@ case 'click':
 default:
     break;
 }
-$js_messages['strGoToLink'] = __('Go to link');
-$js_messages['strColNameCopyTitle'] = __('Copy column name');
+$js_messages['strGoToLink'] = __('Go to link:');
+$js_messages['strColNameCopyTitle'] = __('Copy column name.');
 $js_messages['strColNameCopyText'] = __('Right-click the column name to copy it to your clipboard.');
-$js_messages['strShowDataRowLink'] = __('Show data row(s)');
+$js_messages['strShowDataRowLink'] = __('Show data row(s).');
 
 /* password generation */
 $js_messages['strGeneratePassword'] = __('Generate password');
@@ -371,6 +469,10 @@ $js_messages['strMore'] = __('More');
 /* navigation panel */
 $js_messages['strShowPanel'] = __('Show Panel');
 $js_messages['strHidePanel'] = __('Hide Panel');
+$js_messages['strUnhideNavItem'] = __('Show hidden navigation tree items.');
+$js_messages['linkWithMain'] = __('Link with main panel');
+$js_messages['unlinkWithMain'] = __('Unlink from main panel');
+$js_messages['strHoverFastFilter'] = __('To search all databases on server, press Enter after a search term');
 
 /* microhistory */
 $js_messages['strInvalidPage'] = __('The requested page was not found in the history, it may have expired.');
@@ -381,6 +483,52 @@ $js_messages['strNewerVersion'] = __('A newer version of phpMyAdmin is available
 $js_messages['strLatestAvailable'] = __(', latest stable version:');
 $js_messages['strUpToDate'] = __('up to date');
 
+$js_messages['strCreateView'] = __('Create view');
+
+/* Error Reporting */
+$js_messages['strSendErrorReport'] = __("Send Error Report");
+$js_messages['strSubmitErrorReport'] = __("Submit Error Report");
+$js_messages['strErrorOccurred'] = __(
+    "A fatal JavaScript error has occurred. Would you like to send an error report?"
+);
+$js_messages['strChangeReportSettings'] = __("Change Report Settings");
+$js_messages['strShowReportDetails'] = __("Show Report Details");
+$js_messages['strIgnore'] = __("Ignore");
+$js_messages['strTimeOutError'] = __(
+    "Your export is incomplete, due to a low execution time limit at the PHP level!"
+);
+
+$js_messages['strTooManyInputs'] = __(
+    "Warning: a form on this page has more than %d fields. On submission, "
+    . "some of the fields might be ignored, due to PHP's "
+    . "max_input_vars configuration."
+);
+
+$js_messages['phpErrorsFound'] = '<div class="error">'
+    . __('Some errors have been detected on the server!')
+    . '<div>'
+    . __('Please look at the bottom of this window.')
+    . '<input id="pma_ignore_errors_popup" type="submit" value="'
+    . __('Ignore')
+    . '" style="float: right; margin: 20px;">'
+    . '<input id="pma_ignore_all_errors_popup" type="submit" value="'
+    . __('Ignore All')
+    . '" style="float: right; margin: 20px;">'
+    . '</div></div>';
+
+$js_messages['phpErrorsBeingSubmitted'] = '<div class="error">'
+    . __('Some errors have been detected on the server!')
+    . '<br/>'
+    . __('As per your settings, they are being submitted currently, please be patient.')
+    . '<br/>'
+    . '<img src="'
+    . ($_SESSION['PMA_Theme']->getImgPath('ajax_clock_small.gif'))
+    . '" width="16" height="16" alt="ajax clock"/>'
+    . '</div>';
+
+$js_messages['strConsoleRequeryConfirm'] = __('Execute this query again?');
+$js_messages['strConsoleDeleteBookmarkConfirm'] = __('Do you really want to delete this bookmark?');
+$js_messages['strNoLocalStorage'] = __('Your web browser does not support local storage of settings or the quota limit has been reached, some features may not work properly for you. In Safari, such problem is commonly caused by "Private Mode Browsing".');
 
 echo "var PMA_messages = new Array();\n";
 foreach ($js_messages as $name => $js_message) {
@@ -388,13 +536,19 @@ foreach ($js_messages as $name => $js_message) {
 }
 
 /* Calendar */
-echo "var themeCalendarImage = '" . $GLOBALS['pmaThemeImage'] . 'b_calendar.png' . "';\n";
+echo "var themeCalendarImage = '" . $GLOBALS['pmaThemeImage']
+    . 'b_calendar.png' . "';\n";
 
 /* Image path */
 echo "var pmaThemeImage = '" . $GLOBALS['pmaThemeImage'] . "';\n";
 
-/* Version */
-echo "var pmaversion = '" . PMA_VERSION . "';\n";
+echo "var mysql_doc_template = '" . PMA_Util::getMySQLDocuURL('%s') . "';\n";
+
+//Max input vars allowed by PHP.
+$maxInputVars = ini_get('max_input_vars');
+echo 'var maxInputVars = '
+    . (false === $maxInputVars || '' == $maxInputVars ? 'false' : $maxInputVars)
+    . ';' . "\n";
 
 echo "if ($.datepicker) {\n";
 /* l10n: Display text for calendar close link */
@@ -510,11 +664,19 @@ PMA_printJsValue(
 /* l10n: Column header for week of the year in calendar */
 PMA_printJsValue("$.datepicker.regional['']['weekHeader']", __('Wk'));
 
-/* l10n: Month-year order for calendar, use either "calendar-month-year" or "calendar-year-month". */
-PMA_printJsValue("$.datepicker.regional['']['showMonthAfterYear']", (__('calendar-month-year') == 'calendar-year-month'));
+PMA_printJsValue(
+    "$.datepicker.regional['']['showMonthAfterYear']",
+    /* l10n: Month-year order for calendar, use either "calendar-month-year"
+    * or "calendar-year-month".
+    */
+    (__('calendar-month-year') == 'calendar-year-month')
+);
 /* l10n: Year suffix for calendar, "none" is empty. */
 $year_suffix = _pgettext('Year suffix', 'none');
-PMA_printJsValue("$.datepicker.regional['']['yearSuffix']", ($year_suffix == 'none' ? '' : $year_suffix));
+PMA_printJsValue(
+    "$.datepicker.regional['']['yearSuffix']",
+    ($year_suffix == 'none' ? '' : $year_suffix)
+);
 ?>
 $.extend($.datepicker._defaults, $.datepicker.regional['']);
 } /* if ($.datepicker) */
