@@ -6,6 +6,9 @@ var temp_chart_title;
 var currentChart = null;
 var currentSettings = null;
 
+var dateTimeCols = [];
+var numericCols = [];
+
 function extractDate(dateString) {
     var matches, match;
     var dateTimeRegExp = /[0-9]{4}-[0-9]{2}-[0-9]{2} [0-9]{2}:[0-9]{2}:[0-9]{2}/;
@@ -14,12 +17,12 @@ function extractDate(dateString) {
     matches = dateTimeRegExp.exec(dateString);
     if (matches !== null && matches.length > 0) {
         match = matches[0];
-        return new Date(match.substr(0, 4), match.substr(5, 2), match.substr(8, 2), match.substr(11, 2), match.substr(14, 2), match.substr(17, 2));
+        return new Date(match.substr(0, 4), parseInt(match.substr(5, 2), 10) - 1, match.substr(8, 2), match.substr(11, 2), match.substr(14, 2), match.substr(17, 2));
     } else {
         matches = dateRegExp.exec(dateString);
         if (matches !== null && matches.length > 0) {
             match = matches[0];
-            return new Date(match.substr(0, 4), match.substr(5, 2), match.substr(8, 2));
+            return new Date(match.substr(0, 4), parseInt(match.substr(5, 2), 10) - 1, match.substr(8, 2));
         }
     }
     return null;
@@ -47,18 +50,13 @@ function PMA_queryChart(data, columnNames, settings) {
         },
         axes : {
             xaxis : {
-                label : settings.xaxisLabel
+                label : escapeHtml(settings.xaxisLabel)
             },
             yaxis : {
                 label : settings.yaxisLabel
             }
         },
-        stackSeries : settings.stackSeries,
-        highlighter: {
-            show: true,
-            showTooltip: true,
-            tooltipAxes: 'xy'
-        }
+        stackSeries : settings.stackSeries
     };
 
     // create the chart
@@ -69,37 +67,77 @@ function PMA_queryChart(data, columnNames, settings) {
     var dataTable = new DataTable();
     if (settings.type == 'timeline') {
         dataTable.addColumn(ColumnType.DATE, columnNames[settings.mainAxis]);
+    } else if (settings.type == 'scatter') {
+        dataTable.addColumn(ColumnType.NUMBER, columnNames[settings.mainAxis]);
     } else {
         dataTable.addColumn(ColumnType.STRING, columnNames[settings.mainAxis]);
     }
-    $.each(settings.selectedSeries, function (index, element) {
-        dataTable.addColumn(ColumnType.NUMBER, columnNames[element]);
-    });
 
-    // set data to the data table
-    var columnsToExtract = [ settings.mainAxis ];
-    $.each(settings.selectedSeries, function (index, element) {
-        columnsToExtract.push(element);
-    });
-    var values = [], newRow, row, col;
-    for (var i = 0; i < data.length; i++) {
-        row = data[i];
-        newRow = [];
-        for (var j = 0; j < columnsToExtract.length; j++) {
-            col = columnNames[columnsToExtract[j]];
-            if (j === 0) {
-                if (settings.type == 'timeline') { // first column is date type
-                    newRow.push(extractDate(row[col]));
-                } else { // first column is string type
-                    newRow.push(row[col]);
+    if (settings.seriesColumn === null) {
+        $.each(settings.selectedSeries, function (index, element) {
+            dataTable.addColumn(ColumnType.NUMBER, columnNames[element]);
+        });
+
+        // set data to the data table
+        var columnsToExtract = [ settings.mainAxis ];
+        $.each(settings.selectedSeries, function (index, element) {
+            columnsToExtract.push(element);
+        });
+        var values = [], newRow, row, col;
+        for (var i = 0; i < data.length; i++) {
+            row = data[i];
+            newRow = [];
+            for (var j = 0; j < columnsToExtract.length; j++) {
+                col = columnNames[columnsToExtract[j]];
+                if (j === 0) {
+                    if (settings.type == 'timeline') { // first column is date type
+                        newRow.push(extractDate(row[col]));
+                    } else if (settings.type == 'scatter') {
+                        newRow.push(parseFloat(row[col]));
+                    } else { // first column is string type
+                        newRow.push(row[col]);
+                    }
+                } else { // subsequent columns are of type, number
+                    newRow.push(parseFloat(row[col]));
                 }
-            } else { // subsequent columns are of type, number
-                newRow.push(parseFloat(row[col]));
+            }
+            values.push(newRow);
+        }
+        dataTable.setData(values);
+    } else {
+        var seriesNames = {}, seriesNumber = 1;
+        var seriesColumnName = columnNames[settings.seriesColumn];
+        for (var i = 0; i < data.length; i++) {
+            if (! seriesNames[data[i][seriesColumnName]]) {
+                seriesNames[data[i][seriesColumnName]] = seriesNumber;
+                seriesNumber++;
             }
         }
-        values.push(newRow);
+
+        $.each(seriesNames, function (seriesName, seriesNumber) {
+            dataTable.addColumn(ColumnType.NUMBER, seriesName);
+        });
+
+        var valueMap = {}, xValue, value;
+        var mainAxisName = columnNames[settings.mainAxis];
+        var valueColumnName = columnNames[settings.valueColumn];
+        for (var i = 0; i < data.length; i++) {
+            xValue = data[i][mainAxisName];
+            value = valueMap[xValue];
+            if (! value) {
+                value = [xValue];
+                valueMap[xValue] = value;
+            }
+            seriesNumber = seriesNames[data[i][seriesColumnName]];
+            value[seriesNumber] = parseFloat(data[i][valueColumnName]);
+        }
+
+        var values = [];
+        $.each(valueMap, function(index, value) {
+            values.push(value);
+        });
+        dataTable.setData(values);
     }
-    dataTable.setData(values);
 
     // draw the chart and return the chart object
     chart.draw(dataTable, jqPlotSettings);
@@ -110,7 +148,7 @@ function drawChart() {
     currentSettings.width = $('#resizer').width() - 20;
     currentSettings.height = $('#resizer').height() - 20;
 
-    // todo: a better way using .redraw() ?
+    // TODO: a better way using .redraw() ?
     if (currentChart !== null) {
         currentChart.destroy();
     }
@@ -126,6 +164,12 @@ function drawChart() {
     }
 }
 
+function saveChartAsImage() {
+    if (currentChart !== null) {
+        currentChart.saveAsImage();
+    }
+}
+
 function getSelectedSeries() {
     var val = $('select[name="chartSeries"]').val() || [];
     var ret = [];
@@ -135,18 +179,67 @@ function getSelectedSeries() {
     return ret;
 }
 
+function onXAxisChange() {
+    var $xAxisSelect = $('select[name="chartXAxis"]');
+    currentSettings.mainAxis = parseInt($xAxisSelect.val(), 10);
+    if (dateTimeCols.indexOf(currentSettings.mainAxis) != -1) {
+        $('span.span_timeline').show();
+    } else {
+        $('span.span_timeline').hide();
+        if (currentSettings.type == 'timeline') {
+            $('input#radio_line').prop('checked', true);
+            currentSettings.type = 'line';
+        }
+    }
+    if (numericCols.indexOf(currentSettings.mainAxis) != -1) {
+        $('span.span_scatter').show();
+    } else {
+        $('span.span_scatter').hide();
+        if (currentSettings.type == 'scatter') {
+            $('input#radio_line').prop('checked', true);
+            currentSettings.type = 'line';
+        }
+    }
+    var xaxis_title = $xAxisSelect.children('option:selected').text();
+    $('input[name="xaxis_label"]').val(xaxis_title);
+    currentSettings.xaxisLabel = xaxis_title;
+}
+
+function onDataSeriesChange() {
+    var $seriesSelect = $('select[name="chartSeries"]');
+    currentSettings.selectedSeries = getSelectedSeries();
+    var yaxis_title;
+    if (currentSettings.selectedSeries.length == 1) {
+        $('span.span_pie').show();
+        yaxis_title = $seriesSelect.children('option:selected').text();
+    } else {
+        $('span.span_pie').hide();
+        if (currentSettings.type == 'pie') {
+            $('input#radio_line').prop('checked', true);
+            currentSettings.type = 'line';
+        }
+        yaxis_title = PMA_messages.strYValues;
+    }
+    $('input[name="yaxis_label"]').val(yaxis_title);
+    currentSettings.yaxisLabel = yaxis_title;
+}
+
 /**
  * Unbind all event handlers before tearing down a page
  */
 AJAX.registerTeardown('tbl_chart.js', function () {
     $('input[name="chartType"]').unbind('click');
     $('input[name="barStacked"]').unbind('click');
+    $('input[name="chkAlternative"]').unbind('click');
     $('input[name="chartTitle"]').unbind('focus').unbind('keyup').unbind('blur');
     $('select[name="chartXAxis"]').unbind('change');
     $('select[name="chartSeries"]').unbind('change');
+    $('select[name="chartSeriesColumn"]').unbind('change');
+    $('select[name="chartValueColumn"]').unbind('change');
     $('input[name="xaxis_label"]').unbind('keyup');
     $('input[name="yaxis_label"]').unbind('keyup');
     $('#resizer').unbind('resizestop');
+    $('#saveChart').unbind('click');
 });
 
 AJAX.registerOnload('tbl_chart.js', function () {
@@ -176,26 +269,47 @@ AJAX.registerOnload('tbl_chart.js', function () {
         title : $('input[name="chartTitle"]').val(),
         stackSeries : false,
         mainAxis : parseInt($('select[name="chartXAxis"]').val(), 10),
-        selectedSeries : getSelectedSeries()
+        selectedSeries : getSelectedSeries(),
+        seriesColumn : null
     };
 
     // handle chart type changes
     $('input[name="chartType"]').click(function () {
-        currentSettings.type = $(this).val();
-        drawChart();
-        if ($(this).val() == 'bar' || $(this).val() == 'column' ||
-            $(this).val() == 'line' || $(this).val() == 'area' ||
-            $(this).val() == 'timeline' || $(this).val() == 'spline'
-        ) {
+        var type = currentSettings.type = $(this).val();
+        if (type == 'bar' || type == 'column' || type == 'area') {
             $('span.barStacked').show();
         } else {
+            $('input[name="barStacked"]').attr('checked', false);
+            $.extend(true, currentSettings, {stackSeries : false});
             $('span.barStacked').hide();
         }
+        drawChart();
+    });
+
+    // handle chosing alternative data format
+    $('input[name="chkAlternative"]').click(function () {
+        var $seriesColumn = $('select[name="chartSeriesColumn"]');
+        var $valueColumn  = $('select[name="chartValueColumn"]');
+        var $chartSeries  = $('select[name="chartSeries"]');
+        if ($(this).is(':checked')) {
+            $seriesColumn.attr('disabled', false);
+            $valueColumn.attr('disabled', false);
+            $chartSeries.attr('disabled', true);
+            currentSettings.seriesColumn = parseInt($seriesColumn.val(), 10);
+            currentSettings.valueColumn = parseInt($valueColumn.val(), 10);
+        } else {
+            $seriesColumn.attr('disabled', true);
+            $valueColumn.attr('disabled', true);
+            $chartSeries.attr('disabled', false);
+            currentSettings.seriesColumn = null;
+            currentSettings.valueColumn = null;
+        }
+        drawChart();
     });
 
     // handle stacking for bar, column and area charts
     $('input[name="barStacked"]').click(function () {
-        if (this.checked) {
+        if ($(this).is(':checked')) {
             $.extend(true, currentSettings, {stackSeries : true});
         } else {
             $.extend(true, currentSettings, {stackSeries : false});
@@ -204,62 +318,55 @@ AJAX.registerOnload('tbl_chart.js', function () {
     });
 
     // handle changes in chart title
-    $('input[name="chartTitle"]').focus(function () {
+    $('input[name="chartTitle"]')
+    .focus(function () {
         temp_chart_title = $(this).val();
-    }).keyup(function () {
+    })
+    .keyup(function () {
         var title = $(this).val();
         if (title.length === 0) {
             title = ' ';
         }
         currentSettings.title = $('input[name="chartTitle"]').val();
         drawChart();
-    }).blur(function () {
+    })
+    .blur(function () {
         if ($(this).val() != temp_chart_title) {
             drawChart();
         }
     });
 
-    var dateTimeCols = [];
     var vals = $('input[name="dateTimeCols"]').val().split(' ');
     $.each(vals, function (i, v) {
         dateTimeCols.push(parseInt(v, 10));
     });
 
+    vals = $('input[name="numericCols"]').val().split(' ');
+    $.each(vals, function (i, v) {
+        numericCols.push(parseInt(v, 10));
+    });
+
     // handle changing the x-axis
     $('select[name="chartXAxis"]').change(function () {
-        currentSettings.mainAxis = parseInt($(this).val(), 10);
-        if (dateTimeCols.indexOf(currentSettings.mainAxis) != -1) {
-            $('span.span_timeline').show();
-        } else {
-            $('span.span_timeline').hide();
-            if (currentSettings.type == 'timeline') {
-                $('input#radio_line').prop('checked', true);
-                currentSettings.type = 'line';
-            }
-        }
-        var xaxis_title = $(this).children('option:selected').text();
-        $('input[name="xaxis_label"]').val(xaxis_title);
-        currentSettings.xaxisLabel = xaxis_title;
+        onXAxisChange();
         drawChart();
     });
 
     // handle changing the selected data series
     $('select[name="chartSeries"]').change(function () {
-        currentSettings.selectedSeries = getSelectedSeries();
-        var yaxis_title;
-        if (currentSettings.selectedSeries.length == 1) {
-            $('span.span_pie').show();
-            yaxis_title = $(this).children('option:selected').text();
-        } else {
-            $('span.span_pie').hide();
-            if (currentSettings.type == 'pie') {
-                $('input#radio_line').prop('checked', true);
-                currentSettings.type = 'line';
-            }
-            yaxis_title = PMA_messages.strYValues;
-        }
-        $('input[name="yaxis_label"]').val(yaxis_title);
-        currentSettings.yaxisLabel = yaxis_title;
+        onDataSeriesChange();
+        drawChart();
+    });
+
+    // handle changing the series column
+    $('select[name="chartSeriesColumn"]').change(function () {
+        currentSettings.seriesColumn = parseInt($(this).val(), 10);
+        drawChart();
+    });
+
+    // handle changing the value column
+    $('select[name="chartValueColumn"]').change(function () {
+        currentSettings.valueColumn = parseInt($(this).val(), 10);
         drawChart();
     });
 
@@ -273,6 +380,13 @@ AJAX.registerOnload('tbl_chart.js', function () {
         drawChart();
     });
 
+    $('#saveChart').click(function() {
+        saveChartAsImage();
+    });
+
+    onXAxisChange();
+    onDataSeriesChange();
+
     $("#tblchartform").submit();
 });
 
@@ -289,7 +403,7 @@ $("#tblchartform").live('submit', function (event) {
 
     var $form = $(this);
     if (codemirror_editor) {
-        $form[0].elements['sql_query'].value = codemirror_editor.getValue();
+        $form[0].elements.sql_query.value = codemirror_editor.getValue();
     }
     if (!checkSqlQuery($form[0])) {
         return false;
@@ -300,7 +414,7 @@ $("#tblchartform").live('submit', function (event) {
     PMA_prepareForAjaxRequest($form);
 
     $.post($form.attr('action'), $form.serialize(), function (data) {
-        if (data.success === true) {
+        if (typeof data !== 'undefined' && data.success === true) {
             $('.success').fadeOut();
             if (typeof data.chartData != 'undefined') {
                 chart_data = jQuery.parseJSON(data.chartData);
@@ -315,8 +429,6 @@ $("#tblchartform").live('submit', function (event) {
         } else {
             PMA_ajaxRemoveMessage($msgbox);
             PMA_ajaxShowMessage(data.error, false);
-            chart_data = null;
-            drawChart();
         }
         PMA_ajaxRemoveMessage($msgbox);
     }, "json"); // end $.post()
