@@ -72,6 +72,13 @@ class PMA_DbQbe
      * @var array
      */
     private $_criteriaRowInsert;
+    /**
+     * Whether to delete a row
+     *
+     * @access private
+     * @var array
+     */
+    private $_criteriaRowDelete;
     /**
      * Already set criteria values
      *
@@ -101,7 +108,7 @@ class PMA_DbQbe
      */
     private $_criteriaAndOrRow;
     /**
-     * Larget width of a column
+     * Large width of a column
      *
      * @access private
      * @var string
@@ -111,7 +118,7 @@ class PMA_DbQbe
      * Minimum width of a column
      *
      * @access private
-     * @var string
+     * @var int
      */
     private $_form_column_width;
     /**
@@ -143,12 +150,19 @@ class PMA_DbQbe
      */
     private $_curCriteria;
     /**
-     * Current criteria AND/OR column realtions
+     * Current criteria AND/OR column relations
      *
      * @access private
      * @var array
      */
     private $_curAndOrCol;
+    /**
+     * Current criteria AND/OR row relations
+     *
+     * @access private
+     * @var array
+     */
+    private $_curAndOrRow;
     /**
      * New column count in case of add/delete
      *
@@ -163,15 +177,64 @@ class PMA_DbQbe
      * @var integer
      */
     private $_new_row_count;
+    /**
+     * List of saved searches
+     *
+     * @access private
+     * @var array
+     */
+    private $_savedSearchList = null;
+    /**
+     * Current search
+     *
+     * @access private
+     * @var PMA_SavedSearches
+     */
+    private $_currentSearch = null;
+
+    /**
+     * Initialize criterias
+     *
+     * @return static
+     */
+    private function _loadCriterias()
+    {
+        if (null === $this->_currentSearch
+            || null === $this->_currentSearch->getCriterias()
+        ) {
+            return $this;
+        }
+
+        $criterias = $this->_currentSearch->getCriterias();
+        $_REQUEST = $criterias + $_REQUEST;
+
+        return $this;
+    }
+
+    /**
+     * Getter for current search
+     *
+     * @return PMA_SavedSearches
+     */
+    private function _getCurrentSearch()
+    {
+        return $this->_currentSearch;
+    }
 
     /**
      * Public Constructor
      *
-     * @param string $db Database name
+     * @param string            $dbname          Database name
+     * @param array             $savedSearchList List of saved searches
+     * @param PMA_SavedSearches $currentSearch   Current search id
      */
-    public function __construct($db)
-    {
-        $this->_db = $db;
+    public function __construct(
+        $dbname, $savedSearchList = array(), $currentSearch = null
+    ) {
+        $this->_db = $dbname;
+        $this->_savedSearchList = $savedSearchList;
+        $this->_currentSearch = $currentSearch;
+        $this->_loadCriterias();
         // Sets criteria parameters
         $this->_setSearchParams();
         $this->_setCriteriaTablesAndColumns();
@@ -184,26 +247,7 @@ class PMA_DbQbe
      */
     private function _setSearchParams()
     {
-        // sets column count
-        $criteriaColumnCount = PMA_ifSetOr(
-            $_REQUEST['criteriaColumnCount'],
-            3,
-            'numeric'
-        );
-        $criteriaColumnAdd = PMA_ifSetOr(
-            $_REQUEST['criteriaColumnAdd'],
-            0,
-            'numeric'
-        );
-        $this->_criteria_column_count = max(
-            $criteriaColumnCount + $criteriaColumnAdd,
-            0
-        );
-
-        // sets row count
-        $rows = PMA_ifSetOr($_REQUEST['rows'],    0, 'numeric');
-        $criteriaRowAdd = PMA_ifSetOr($_REQUEST['criteriaRowAdd'], 0, 'numeric');
-        $this->_criteria_row_count = max($rows + $criteriaRowAdd, 0);
+        $criteriaColumnCount = $this->_initializeCriteriasCount();
 
         $this->_criteriaColumnInsert = PMA_ifSetOr(
             $_REQUEST['criteriaColumnInsert'],
@@ -290,7 +334,7 @@ class PMA_DbQbe
                     $this->_columnNames[] = $each_column;
                     // increase the width if necessary
                     $this->_form_column_width = max(
-                        strlen($each_column),
+                        /*overload*/mb_strlen($each_column),
                         $this->_form_column_width
                     );
                 } // end foreach
@@ -313,7 +357,8 @@ class PMA_DbQbe
     {
         $html_output = '';
         $html_output .= '<td class="center">';
-        $html_output .= '<select name="criteriaColumn[' . $column_number . ']" size="1">';
+        $html_output .= '<select name="criteriaColumn[' . $column_number
+            . ']" size="1">';
         $html_output .= '<option value="">&nbsp;</option>';
         foreach ($this->_columnNames as $column) {
             $html_output .= '<option value="' . htmlspecialchars($column) . '"'
@@ -363,7 +408,11 @@ class PMA_DbQbe
         $html_output = '<tr class="odd noclick">';
         $html_output .= '<th>' . __('Column:') . '</th>';
         $new_column_count = 0;
-        for ($column_index = 0; $column_index < $this->_criteria_column_count; $column_index++) {
+        for (
+            $column_index = 0;
+            $column_index < $this->_criteria_column_count;
+            $column_index++
+        ) {
             if (isset($this->_criteriaColumnInsert[$column_index])
                 && $this->_criteriaColumnInsert[$column_index] == 'on'
             ) {
@@ -405,45 +454,50 @@ class PMA_DbQbe
         $html_output = '<tr class="even noclick">';
         $html_output .= '<th>' . __('Sort:') . '</th>';
         $new_column_count = 0;
-        for ($column_index = 0; $column_index < $this->_criteria_column_count; $column_index++) {
+
+        for (
+            $colInd = 0;
+            $colInd < $this->_criteria_column_count;
+            $colInd++
+        ) {
             if (! empty($this->_criteriaColumnInsert)
-                && isset($this->_criteriaColumnInsert[$column_index])
-                && $this->_criteriaColumnInsert[$column_index] == 'on'
+                && isset($this->_criteriaColumnInsert[$colInd])
+                && $this->_criteriaColumnInsert[$colInd] == 'on'
             ) {
                 $html_output .= $this->_getSortSelectCell($new_column_count);
                 $new_column_count++;
             } // end if
 
             if (! empty($this->_criteriaColumnDelete)
-                && isset($this->_criteriaColumnDelete[$column_index])
-                && $this->_criteriaColumnDelete[$column_index] == 'on'
+                && isset($this->_criteriaColumnDelete[$colInd])
+                && $this->_criteriaColumnDelete[$colInd] == 'on'
             ) {
                 continue;
             }
             // If they have chosen all fields using the * selector,
             // then sorting is not available, Fix for Bug #570698
-            if (isset($_REQUEST['criteriaSort'][$column_index])
-                && isset($_REQUEST['criteriaColumn'][$column_index])
-                && substr($_REQUEST['criteriaColumn'][$column_index], -2) == '.*'
+            if (isset($_REQUEST['criteriaSort'][$colInd])
+                && isset($_REQUEST['criteriaColumn'][$colInd])
+                && /*overload*/mb_substr($_REQUEST['criteriaColumn'][$colInd], -2) == '.*'
             ) {
-                $_REQUEST['criteriaSort'][$column_index] = '';
+                $_REQUEST['criteriaSort'][$colInd] = '';
             } //end if
             // Set asc_selected
-            if (isset($_REQUEST['criteriaSort'][$column_index])
-                && $_REQUEST['criteriaSort'][$column_index] == 'ASC'
+            if (isset($_REQUEST['criteriaSort'][$colInd])
+                && $_REQUEST['criteriaSort'][$colInd] == 'ASC'
             ) {
                 $this->_curSort[$new_column_count]
-                    = $_REQUEST['criteriaSort'][$column_index];
+                    = $_REQUEST['criteriaSort'][$colInd];
                 $asc_selected = ' selected="selected"';
             } else {
                 $asc_selected = '';
             } // end if
             // Set desc selected
-            if (isset($_REQUEST['criteriaSort'][$column_index])
-                && $_REQUEST['criteriaSort'][$column_index] == 'DESC'
+            if (isset($_REQUEST['criteriaSort'][$colInd])
+                && $_REQUEST['criteriaSort'][$colInd] == 'DESC'
             ) {
                 $this->_curSort[$new_column_count]
-                    = $_REQUEST['criteriaSort'][$column_index];
+                    = $_REQUEST['criteriaSort'][$colInd];
                 $desc_selected = ' selected="selected"';
             } else {
                 $desc_selected = '';
@@ -467,7 +521,11 @@ class PMA_DbQbe
         $html_output = '<tr class="odd noclick">';
         $html_output .= '<th>' . __('Show:') . '</th>';
         $new_column_count = 0;
-        for ($column_index = 0; $column_index < $this->_criteria_column_count; $column_index++) {
+        for (
+            $column_index = 0;
+            $column_index < $this->_criteria_column_count;
+            $column_index++
+        ) {
             if (! empty($this->_criteriaColumnInsert)
                 && isset($this->_criteriaColumnInsert[$column_index])
                 && $this->_criteriaColumnInsert[$column_index] == 'on'
@@ -512,7 +570,11 @@ class PMA_DbQbe
         $html_output = '<tr class="even noclick">';
         $html_output .= '<th>' . __('Criteria:') . '</th>';
         $new_column_count = 0;
-        for ($column_index = 0; $column_index < $this->_criteria_column_count; $column_index++) {
+        for (
+            $column_index = 0;
+            $column_index < $this->_criteria_column_count;
+            $column_index++
+        ) {
             if (! empty($this->_criteriaColumnInsert)
                 && isset($this->_criteriaColumnInsert[$column_index])
                 && $this->_criteriaColumnInsert[$column_index] == 'on'
@@ -705,6 +767,7 @@ class PMA_DbQbe
                 $this->_curAndOrCol[$new_column_count]
                     = $this->_criteriaAndOrColumn[$column_index];
             }
+            $checked_options = array();
             if (isset($this->_criteriaAndOrColumn[$column_index])
                 && $this->_criteriaAndOrColumn[$column_index] == 'or'
             ) {
@@ -729,7 +792,7 @@ class PMA_DbQbe
      * with AND/OR relationship modification options
      *
      * @param integer $row_index       Number of criteria row
-     * @param string  $checked_options If checked
+     * @param array   $checked_options If checked
      *
      * @return string HTML
      */
@@ -786,28 +849,32 @@ class PMA_DbQbe
     {
         $html_output = '';
         $new_column_count = 0;
-        for ($column_index = 0; $column_index < $this->_criteria_column_count; $column_index++) {
-            if (! empty($this->_criteriaColumnInsert)
+        for (
+            $column_index = 0;
+            $column_index < $this->_criteria_column_count;
+            $column_index++
+        ) {
+            if (!empty($this->_criteriaColumnInsert)
                 && isset($this->_criteriaColumnInsert[$column_index])
                 && $this->_criteriaColumnInsert[$column_index] == 'on'
             ) {
-                $or = 'Or' . $new_row_index . '[' . $new_column_count . ']';
+                $orFieldName = 'Or' . $new_row_index . '[' . $new_column_count . ']';
                 $html_output .= '<td class="center">';
                 $html_output .= '<input type="text"'
-                    . ' name="Or' . $or . '" class="textfield"'
+                    . ' name="Or' . $orFieldName . '" class="textfield"'
                     . ' style="width: ' . $this->_realwidth . '" size="20" />';
                 $html_output .= '</td>';
                 $new_column_count++;
             } // end if
-            if (! empty($this->_criteriaColumnDelete)
+            if (!empty($this->_criteriaColumnDelete)
                 && isset($this->_criteriaColumnDelete[$column_index])
                 && $this->_criteriaColumnDelete[$column_index] == 'on'
             ) {
                 continue;
             }
             $or = 'Or' . $new_row_index;
-            if (! empty($_POST[$or]) && isset($_POST[$or][$column_index])) {
-                $tmp_or = $_POST[$or][$column_index];
+            if (! empty($_REQUEST[$or]) && isset($_REQUEST[$or][$column_index])) {
+                $tmp_or = $_REQUEST[$or][$column_index];
             } else {
                 $tmp_or     = '';
             }
@@ -817,8 +884,9 @@ class PMA_DbQbe
                 . ' value="' . htmlspecialchars($tmp_or) . '" class="textfield"'
                 . ' style="width: ' . $this->_realwidth . '" size="20" />';
             $html_output .= '</td>';
-            if (! empty(${$or}) && isset(${$or}[$column_index])) {
-                $GLOBALS[${'cur' . $or}][$new_column_count] = ${$or}[$column_index];
+            if (!empty(${$or}) && isset(${$or}[$column_index])) {
+                $GLOBALS[${'cur' . $or}][$new_column_count]
+                    = ${$or}[$column_index];
             }
             $new_column_count++;
         } // end for
@@ -836,6 +904,7 @@ class PMA_DbQbe
         $html_output = '';
         $new_row_count = 0;
         $odd_row = true;
+        $checked_options = array();
         for (
         $row_index = 0;
         $row_index <= $this->_criteria_row_count;
@@ -846,7 +915,8 @@ class PMA_DbQbe
             ) {
                 $checked_options['or']  = ' checked="checked"';
                 $checked_options['and'] = '';
-                $html_output .= '<tr class="' . ($odd_row ? 'odd' : 'even') . ' noclick">';
+                $html_output .= '<tr class="' . ($odd_row ? 'odd' : 'even')
+                    . ' noclick">';
                 $html_output .= $this->_getInsDelAndOrCell(
                     $new_row_count, $checked_options
                 );
@@ -875,7 +945,8 @@ class PMA_DbQbe
                 $checked_options['or']  =  ' checked="checked"';
                 $checked_options['and'] =  '';
             }
-            $html_output .= '<tr class="' . ($odd_row ? 'odd' : 'even') . ' noclick">';
+            $html_output .= '<tr class="' . ($odd_row ? 'odd' : 'even')
+                . ' noclick">';
             $html_output .= $this->_getInsDelAndOrCell(
                 $new_row_count, $checked_options
             );
@@ -899,7 +970,11 @@ class PMA_DbQbe
     {
         $select_clause = '';
         $select_clauses = array();
-        for ($column_index = 0; $column_index < $this->_criteria_column_count; $column_index++) {
+        for (
+            $column_index = 0;
+            $column_index < $this->_criteria_column_count;
+            $column_index++
+        ) {
             if (! empty($this->_curField[$column_index])
                 && isset($this->_curShow[$column_index])
                 && $this->_curShow[$column_index] == 'on'
@@ -935,7 +1010,8 @@ class PMA_DbQbe
                 && isset($this->_curAndOrCol)
             ) {
                 $where_clause .= ' '
-                    . strtoupper($this->_curAndOrCol[$last_where]) . ' ';
+                    . /*overload*/mb_strtoupper($this->_curAndOrCol[$last_where])
+                    . ' ';
             }
             if (! empty($this->_curField[$column_index])
                 && ! empty($this->_curCriteria[$column_index])
@@ -967,18 +1043,21 @@ class PMA_DbQbe
             $column_index++
             ) {
                 if (! empty($this->_curField[$column_index])
-                    && ! empty(${'curOr' . $row_index}[$column_index])
+                    && ! empty($_REQUEST['Or' . $row_index][$column_index])
                     && $column_index
                 ) {
                     $qry_orwhere .= ' '
-                        . strtoupper($this->_curAndOrCol[$last_orwhere]) . ' ';
+                        . /*overload*/mb_strtoupper(
+                            $this->_curAndOrCol[$last_orwhere]
+                        )
+                        . ' ';
                 }
                 if (! empty($this->_curField[$column_index])
-                    && ! empty(${'curOr' . $row_index}[$column_index])
+                    && ! empty($_REQUEST['Or' . $row_index][$column_index])
                 ) {
                     $qry_orwhere .= '(' . $this->_curField[$column_index]
                         .  ' '
-                        .  ${'curOr' . $row_index}[$column_index]
+                        .  $_REQUEST['Or' . $row_index][$column_index]
                         .  ')';
                     $last_orwhere = $column_index;
                     $criteria_cnt++;
@@ -989,7 +1068,7 @@ class PMA_DbQbe
             }
             if (! empty($qry_orwhere)) {
                 $where_clause .= "\n"
-                    .  strtoupper(
+                    .  /*overload*/mb_strtoupper(
                         isset($this->_curAndOrRow[$row_index])
                         ? $this->_curAndOrRow[$row_index] . ' '
                         : ''
@@ -1013,20 +1092,26 @@ class PMA_DbQbe
     {
         $orderby_clause = '';
         $orderby_clauses = array();
+
         for (
-        $column_index = 0;
-        $column_index < $this->_criteria_column_count;
-        $column_index++
+            $column_index = 0;
+            $column_index < $this->_criteria_column_count;
+            $column_index++
         ) {
             // if all columns are chosen with * selector,
             // then sorting isn't available
             // Fix for Bug #570698
-            if (! empty($this->_curField[$column_index])
-                && ! empty($this->_curSort[$column_index])
+            if (empty($this->_curField[$column_index])
+                && empty($this->_curSort[$column_index])
             ) {
-                if (substr($this->_curField[$column_index], -2) == '.*') {
-                    continue;
-                }
+                continue;
+            }
+
+            if (/*overload*/mb_substr($this->_curField[$column_index], -2) == '.*') {
+                continue;
+            }
+
+            if (! empty($this->_curSort[$column_index])) {
                 $orderby_clauses[] = $this->_curField[$column_index] . ' '
                     . $this->_curSort[$column_index];
             }
@@ -1094,7 +1179,6 @@ class PMA_DbQbe
         $where_clause_columns
     ) {
         $GLOBALS['dbi']->selectDb($this->_db);
-        $candidate_columns = array();
 
         // Get unique columns and index columns
         $indexes = $this->_getIndexes(
@@ -1103,43 +1187,37 @@ class PMA_DbQbe
         $unique_columns = $indexes['unique'];
         $index_columns = $indexes['index'];
 
-        // now we want to find the best.
-        if (isset($unique_columns) && count($unique_columns) > 0) {
-            $candidate_columns = $unique_columns;
-            $needsort = 1;
-        } elseif (isset($index_columns) && count($index_columns) > 0) {
-            $candidate_columns = $index_columns;
-            $needsort = 1;
-        } elseif (isset($where_clause_columns) && count($where_clause_columns) > 0) {
-            $candidate_columns = $where_clause_columns;
-            $needsort = 0;
-        } else {
-            $candidate_columns = $all_tables;
-            $needsort = 0;
-        }
+        list($candidate_columns, $needsort)
+            = $this->_getLeftJoinColumnCandidatesBest(
+                $all_tables, $where_clause_columns, $unique_columns, $index_columns
+            );
 
         // If we came up with $unique_columns (very good) or $index_columns (still
         // good) as $candidate_columns we want to check if we have any 'Y' there
         // (that would mean that they were also found in the whereclauses
         // which would be great). if yes, we take only those
-        if ($needsort == 1) {
-            foreach ($candidate_columns as $column => $is_where) {
-                $table = explode('.', $column);
-                $table = $table[0];
-                if ($is_where == 'Y') {
-                    $vg[$column] = $table;
-                } else {
-                    $sg[$column] = $table;
-                }
-            }
-            if (isset($vg)) {
-                $candidate_columns = $vg;
-                // Candidates restricted in index+where
+        if ($needsort != 1) {
+            return $candidate_columns;
+        }
+
+        $vg = array();
+        $sg = array();
+        foreach ($candidate_columns as $column => $is_where) {
+            $table = explode('.', $column);
+            $table = $table[0];
+            if ($is_where == 'Y') {
+                $vg[$column] = $table;
             } else {
-                $candidate_columns = $sg;
-                // None of the candidates where in a where-clause
+                $sg[$column] = $table;
             }
         }
+        if (count($vg) > 0) {
+            $candidate_columns = $vg;
+            // Candidates restricted in index+where
+        } else {
+            $candidate_columns = $sg;
+            // None of the candidates where in a where-clause
+        }
 
         return $candidate_columns;
     }
@@ -1157,46 +1235,77 @@ class PMA_DbQbe
     private function _getMasterTable($all_tables, $all_columns,
         $where_clause_columns, $where_clause_tables
     ) {
-        $master = '';
         if (count($where_clause_tables) == 1) {
             // If there is exactly one column that has a decent where-clause
             // we will just use this
             $master = key($where_clause_tables);
-        } else {
-            // Now let's find out which of the tables has an index
-            // (When the control user is the same as the normal user
-            // because he is using one of his databases as pmadb,
-            // the last db selected is not always the one where we need to work)
-            $candidate_columns = $this->_getLeftJoinColumnCandidates(
-                $all_tables, $all_columns, $where_clause_columns
-            );
-            // If our array of candidates has more than one member we'll just
-            // find the smallest table.
-            // Of course the actual query would be faster if we check for
-            // the Criteria which gives the smallest result set in its table,
-            // but it would take too much time to check this
-            if (count($candidate_columns) > 1) {
-                // Of course we only want to check each table once
-                $checked_tables = $candidate_columns;
-                foreach ($candidate_columns as $table) {
-                    if ($checked_tables[$table] != 1) {
-                        $tsize[$table] = PMA_Table::countRecords(
-                            $this->_db,
-                            $table,
-                            false
-                        );
-                        $checked_tables[$table] = 1;
+            return $master;
+        }
+
+        // Now let's find out which of the tables has an index
+        // (When the control user is the same as the normal user
+        // because he is using one of his databases as pmadb,
+        // the last db selected is not always the one where we need to work)
+        $candidate_columns = $this->_getLeftJoinColumnCandidates(
+            $all_tables, $all_columns, $where_clause_columns
+        );
+
+        // Generally, we need to display all the rows of foreign (referenced)
+        // table, whether they have any matching row in child table or not.
+        // So we select candidate tables which are foreign tables.
+        $foreign_tables = array();
+        foreach ($candidate_columns as $one_table) {
+            $foreigners = PMA_getForeigners($this->_db, $one_table);
+            foreach ($foreigners as $key => $foreigner) {
+                if ($key != 'foreign_keys_data') {
+                    if (in_array($foreigner['foreign_table'], $candidate_columns)) {
+                        $foreign_tables[$foreigner['foreign_table']]
+                            = $foreigner['foreign_table'];
+                    }
+                    continue;
+                }
+                foreach ($foreigner as $one_key) {
+                    if (in_array($one_key['ref_table_name'], $candidate_columns)) {
+                        $foreign_tables[$one_key['ref_table_name']]
+                            = $one_key['ref_table_name'];
                     }
-                    $csize[$table] = $tsize[$table];
                 }
-                asort($csize);
-                reset($csize);
-                $master = key($csize); // Smallest
-            } else {
-                reset($candidate_columns);
-                $master = current($candidate_columns); // Only one single candidate
             }
-        } // end if (exactly one where clause)
+        }
+        if (count($foreign_tables)) {
+            $candidate_columns = $foreign_tables;
+        }
+
+        // If our array of candidates has more than one member we'll just
+        // find the smallest table.
+        // Of course the actual query would be faster if we check for
+        // the Criteria which gives the smallest result set in its table,
+        // but it would take too much time to check this
+        if (!(count($candidate_columns) > 1)) {
+            reset($candidate_columns);
+            $master = current($candidate_columns); // Only one single candidate
+            return $master;
+        }
+
+        // Of course we only want to check each table once
+        $checked_tables = $candidate_columns;
+        $tsize = array();
+        $csize = array();
+        foreach ($candidate_columns as $table) {
+            if ($checked_tables[$table] != 1) {
+                $tsize[$table] = PMA_Table::countRecords(
+                    $this->_db,
+                    $table,
+                    false
+                );
+                $checked_tables[$table] = 1;
+            }
+            $csize[$table] = $tsize[$table];
+        }
+        arsort($csize);
+        reset($csize);
+        $master = key($csize); // Largest
+
         return $master;
     }
 
@@ -1209,11 +1318,12 @@ class PMA_DbQbe
     {
         $where_clause_columns = array();
         $where_clause_tables = array();
+
         // Now we need all tables that we have in the where clause
         for (
-        $column_index = 0;
-        $column_index < count($this->_criteria);
-        $column_index++
+            $column_index = 0, $nb = count($this->_criteria);
+            $column_index < $nb;
+            $column_index++
         ) {
             $current_table = explode('.', $_POST['criteriaColumn'][$column_index]);
             if (empty($current_table[0]) || empty($current_table[1])) {
@@ -1225,8 +1335,8 @@ class PMA_DbQbe
             // Now we know that our array has the same numbers as $criteria
             // we can check which of our columns has a where clause
             if (! empty($this->_criteria[$column_index])) {
-                if (substr($this->_criteria[$column_index], 0, 1) == '='
-                    || stristr($this->_criteria[$column_index], 'is')
+                if (/*overload*/mb_substr($this->_criteria[$column_index], 0, 1) == '='
+                    || /*$pmaString->*/stristr($this->_criteria[$column_index], 'is')
                 ) {
                     $where_clause_columns[$column] = $column;
                     $where_clause_tables[$table]  = $table;
@@ -1242,11 +1352,9 @@ class PMA_DbQbe
     /**
      * Provides FROM clause for building SQL query
      *
-     * @param string $cfgRelation Relation Settings
-     *
-     * @return FROM clause
+     * @return string FROM clause
      */
-    private function _getFromClause($cfgRelation)
+    private function _getFromClause()
     {
         $from_clause = '';
         if (isset($_POST['criteriaColumn']) && count($_POST['criteriaColumn']) > 0) {
@@ -1264,7 +1372,7 @@ class PMA_DbQbe
             } // end while
 
             // Create LEFT JOINS out of Relations
-            if ($cfgRelation['relwork'] && count($all_tables) > 0) {
+            if (count($all_tables) > 0) {
                 // Get tables and columns with valid where clauses
                 $valid_where_clauses = $this->_getWhereClauseTablesAndColumns();
                 $where_clause_tables = $valid_where_clauses['where_clause_tables'];
@@ -1277,7 +1385,7 @@ class PMA_DbQbe
                 $from_clause = PMA_Util::backquote($master)
                     . PMA_getRelatives($all_tables, $master);
 
-            } // end if ($cfgRelation['relwork'] && count($all_tables) > 0)
+            } // end if (count($all_tables) > 0)
         } // end count($_POST['criteriaColumn']) > 0
 
         // In case relations are not defined, just generate the FROM clause
@@ -1291,7 +1399,7 @@ class PMA_DbQbe
     /**
      * Provides the generated SQL query
      *
-     * @param string $cfgRelation Relation Settings
+     * @param array $cfgRelation Relation Settings
      *
      * @return string SQL query
      */
@@ -1301,7 +1409,7 @@ class PMA_DbQbe
         // get SELECT clause
         $sql_query .= $this->_getSelectClause();
         // get FROM clause
-        $from_clause = $this->_getFromClause($cfgRelation);
+        $from_clause = $this->_getFromClause();
         if (! empty($from_clause)) {
             $sql_query .= 'FROM ' . htmlspecialchars($from_clause) . "\n";
         }
@@ -1315,14 +1423,19 @@ class PMA_DbQbe
     /**
      * Provides the generated QBE form
      *
-     * @param string $cfgRelation Relation Settings
+     * @param array $cfgRelation Relation Settings
      *
      * @return string QBE form
      */
     public function getSelectionForm($cfgRelation)
     {
-        $html_output = '<form action="db_qbe.php" method="post">';
+        $html_output = '<form action="db_qbe.php" method="post" id="formQBE">';
         $html_output .= '<fieldset>';
+
+        if ($GLOBALS['cfgRelation']['savedsearcheswork']) {
+            $html_output .= $this->_getSavedSearchesField();
+        }
+
         $html_output .= '<table class="data" style="width: 100%;">';
         // Get table's <tr> elements
         $html_output .= $this->_getColumnNamesRow();
@@ -1333,6 +1446,7 @@ class PMA_DbQbe
         $html_output .= $this->_getModifyColumnsRow();
         $html_output .= '</table>';
         $this->_new_row_count--;
+        $url_params = array();
         $url_params['db'] = $this->_db;
         $url_params['criteriaColumnCount'] = $this->_new_column_count;
         $url_params['rows'] = $this->_new_row_count;
@@ -1370,5 +1484,115 @@ class PMA_DbQbe
         $html_output .= '</form>';
         return $html_output;
     }
+
+    /**
+     * Get fields to display
+     *
+     * @return string
+     */
+    private function _getSavedSearchesField()
+    {
+        $html_output = __('Saved bookmarked search:');
+        $html_output .= ' <select name="searchId" id="searchId">';
+        $html_output .= '<option value="">' . __('New bookmark') . '</option>';
+
+        $currentSearch = $this->_getCurrentSearch();
+        $currentSearchId = null;
+        $currentSearchName = null;
+        if (null != $currentSearch) {
+            $currentSearchId = $currentSearch->getId();
+            $currentSearchName = $currentSearch->getSearchName();
+        }
+
+        foreach ($this->_savedSearchList as $id => $name) {
+            $html_output .= '<option value="' . htmlspecialchars($id)
+                . '" ' . (
+                $id == $currentSearchId
+                    ? 'selected="selected" '
+                    : ''
+                )
+                . '>'
+                . htmlspecialchars($name)
+                . '</option>';
+        }
+        $html_output .= '</select>';
+        $html_output .= '<input type="text" name="searchName" id="searchName" '
+            . 'value="' . $currentSearchName . '" />';
+        $html_output .= '<input type="hidden" name="action" id="action" value="" />';
+        $html_output .= '<input type="submit" name="saveSearch" id="saveSearch" '
+            . 'value="' . __('Create bookmark') . '" />';
+        if (null !== $currentSearchId) {
+            $html_output .= '<input type="submit" name="updateSearch" '
+                . 'id="updateSearch" value="' . __('Update bookmark') . '" />';
+            $html_output .= '<input type="submit" name="deleteSearch" '
+                . 'id="deleteSearch" value="' . __('Delete bookmark') . '" />';
+        }
+
+        return $html_output;
+    }
+
+    /**
+     * Initialize _criteria_column_count
+     *
+     * @return int Previous number of columns
+     */
+    private function _initializeCriteriasCount()
+    {
+        // sets column count
+        $criteriaColumnCount = PMA_ifSetOr(
+            $_REQUEST['criteriaColumnCount'],
+            3,
+            'numeric'
+        );
+        $criteriaColumnAdd = PMA_ifSetOr(
+            $_REQUEST['criteriaColumnAdd'],
+            0,
+            'numeric'
+        );
+        $this->_criteria_column_count = max(
+            $criteriaColumnCount + $criteriaColumnAdd,
+            0
+        );
+
+        // sets row count
+        $rows = PMA_ifSetOr($_REQUEST['rows'], 0, 'numeric');
+        $criteriaRowAdd = PMA_ifSetOr($_REQUEST['criteriaRowAdd'], 0, 'numeric');
+        $this->_criteria_row_count = max($rows + $criteriaRowAdd, 0);
+
+        return $criteriaColumnCount;
+    }
+
+    /**
+     * Get best
+     *
+     * @param array $all_tables           All tables
+     * @param array $where_clause_columns Columns with where clause
+     * @param array $unique_columns       Unique columns
+     * @param array $index_columns        Indexed columns
+     *
+     * @return array
+     */
+    private function _getLeftJoinColumnCandidatesBest(
+        $all_tables, $where_clause_columns, $unique_columns, $index_columns
+    ) {
+        // now we want to find the best.
+        if (isset($unique_columns) && count($unique_columns) > 0) {
+            $candidate_columns = $unique_columns;
+            $needsort = 1;
+            return array($candidate_columns, $needsort);
+        } elseif (isset($index_columns) && count($index_columns) > 0) {
+            $candidate_columns = $index_columns;
+            $needsort = 1;
+            return array($candidate_columns, $needsort);
+        } elseif (isset($where_clause_columns) && count($where_clause_columns) > 0) {
+            $candidate_columns = $where_clause_columns;
+            $needsort = 0;
+            return array($candidate_columns, $needsort);
+        } else {
+            $candidate_columns = $all_tables;
+            $needsort = 0;
+            return array($candidate_columns, $needsort);
+        }
+    }
 }
 ?>
