@@ -20,7 +20,7 @@ class PMA_Menu
      * Server id
      *
      * @access private
-     * @var string
+     * @var int
      */
     private $_server;
     /**
@@ -95,15 +95,13 @@ class PMA_Menu
      */
     private function _getMenu()
     {
-        $tabs = array();
         $url_params = array('db' => $this->_db);
-        $level = '';
 
-        if (strlen($this->_table)) {
+        if (/*overload*/mb_strlen($this->_table)) {
             $tabs = $this->_getTableTabs();
             $url_params['table'] = $this->_table;
             $level = 'table';
-        } else if (strlen($this->_db)) {
+        } else if (/*overload*/mb_strlen($this->_db)) {
             $tabs = $this->_getDbTabs();
             $level = 'db';
         } else {
@@ -131,22 +129,27 @@ class PMA_Menu
     {
         $allowedTabs = PMA_Util::getMenuTabList($level);
         $cfgRelation = PMA_getRelationsParam();
-        if ($cfgRelation['menuswork']) {
-            $groupTable = PMA_Util::backquote($GLOBALS['cfg']['Server']['pmadb'])
+        if (isset($cfgRelation['menuswork']) && $cfgRelation['menuswork']) {
+            $groupTable = PMA_Util::backquote($cfgRelation['db'])
                 . "."
-                . PMA_Util::backquote($GLOBALS['cfg']['Server']['usergroups']);
-            $userTable = PMA_Util::backquote($GLOBALS['cfg']['Server']['pmadb'])
-                . "." . PMA_Util::backquote($GLOBALS['cfg']['Server']['users']);
+                . PMA_Util::backquote($cfgRelation['usergroups']);
+            $userTable = PMA_Util::backquote($cfgRelation['db'])
+                . "." . PMA_Util::backquote($cfgRelation['users']);
 
             $sql_query = "SELECT `tab` FROM " . $groupTable
-                . " WHERE `allowed` = 'N' AND `usergroup` = (SELECT usergroup FROM "
+                . " WHERE `allowed` = 'N'"
+                . " AND `tab` LIKE '" . $level . "%'"
+                . " AND `usergroup` = (SELECT usergroup FROM "
                 . $userTable . " WHERE `username` = '"
                 . PMA_Util::sqlAddSlashes($GLOBALS['cfg']['Server']['user']) . "')";
 
             $result = PMA_queryAsControlUser($sql_query, false);
             if ($result) {
                 while ($row = $GLOBALS['dbi']->fetchAssoc($result)) {
-                    $tabName = substr($row['tab'], strpos($row['tab'], '_') + 1);
+                    $tabName = /*overload*/mb_substr(
+                        $row['tab'],
+                        /*overload*/mb_strpos($row['tab'], '_') + 1
+                    );
                     unset($allowedTabs[$tabName]);
                 }
             }
@@ -171,8 +174,7 @@ class PMA_Menu
             : ':' . $GLOBALS['cfg']['Server']['port'];
 
         $separator = "<span class='separator item'>&nbsp;»</span>";
-        $item = '<a href="%1$s?%2$s" class="item">';
-
+        $item = '<a href="%1$s%2$s" class="item">';
 
         if (PMA_Util::showText('TabsMode')) {
             $item .= '%4$s: ';
@@ -195,7 +197,7 @@ class PMA_Menu
             __('Server')
         );
 
-        if (strlen($this->_db)) {
+        if (/*overload*/mb_strlen($this->_db)) {
             $retval .= $separator;
             if (PMA_Util::showIcons('TabsMode')) {
                 $retval .= PMA_Util::getImage(
@@ -207,13 +209,13 @@ class PMA_Menu
             $retval .= sprintf(
                 $item,
                 $GLOBALS['cfg']['DefaultTabDatabase'],
-                PMA_URL_getCommon($this->_db),
+                PMA_URL_getCommon(array('db' => $this->_db)),
                 htmlspecialchars($this->_db),
                 __('Database')
             );
             // if the table is being dropped, $_REQUEST['purge'] is set to '1'
             // so do not display the table name in upper div
-            if (strlen($this->_table)
+            if (/*overload*/mb_strlen($this->_table)
                 && ! (isset($_REQUEST['purge']) && $_REQUEST['purge'] == '1')
             ) {
                 include './libraries/tbl_info.inc.php';
@@ -230,7 +232,11 @@ class PMA_Menu
                 $retval .= sprintf(
                     $item,
                     $GLOBALS['cfg']['DefaultTabTable'],
-                    PMA_URL_getCommon($this->_db, $this->_table),
+                    PMA_URL_getCommon(
+                        array(
+                            'db' => $this->_db, 'table' => $this->_table
+                        )
+                    ),
                     str_replace(' ', '&nbsp;', htmlspecialchars($this->_table)),
                     $tbl_is_view ? __('View') : __('Table')
                 );
@@ -241,7 +247,7 @@ class PMA_Menu
                 if (! empty($show_comment)
                     && ! isset($GLOBALS['avoid_show_comment'])
                 ) {
-                    if (strstr($show_comment, '; InnoDB free')) {
+                    if (/*overload*/mb_strstr($show_comment, '; InnoDB free')) {
                         $show_comment = preg_replace(
                             '@; InnoDB free:.*?$@',
                             '',
@@ -285,9 +291,11 @@ class PMA_Menu
      */
     private function _getTableTabs()
     {
-        $db_is_information_schema = $GLOBALS['dbi']->isSystemSchema($this->_db);
+        $db_is_system_schema = $GLOBALS['dbi']->isSystemSchema($this->_db);
         $tbl_is_view = PMA_Table::isView($this->_db, $this->_table);
         $is_superuser = $GLOBALS['dbi']->isSuperuser();
+        $isCreateOrGrantUser = $GLOBALS['dbi']->isUserType('grant')
+            || $GLOBALS['dbi']->isUserType('create');
 
         $tabs = array();
 
@@ -312,7 +320,7 @@ class PMA_Menu
             array('tbl_select.php', 'tbl_zoom_select.php', 'tbl_find_replace.php')
         );
 
-        if (! $db_is_information_schema) {
+        if (! $db_is_system_schema) {
             $tabs['insert']['icon'] = 'b_insrow.png';
             $tabs['insert']['link'] = 'tbl_change.php';
             $tabs['insert']['text'] = __('Insert');
@@ -326,12 +334,14 @@ class PMA_Menu
         /**
          * Don't display "Import" for views and information_schema
          */
-        if (! $tbl_is_view && ! $db_is_information_schema) {
+        if (! $tbl_is_view && ! $db_is_system_schema) {
             $tabs['import']['icon'] = 'b_tblimport.png';
             $tabs['import']['link'] = 'tbl_import.php';
             $tabs['import']['text'] = __('Import');
         }
-        if ($is_superuser && ! PMA_DRIZZLE && ! $db_is_information_schema) {
+        if (($is_superuser || $isCreateOrGrantUser)
+            && ! PMA_DRIZZLE && ! $db_is_system_schema
+        ) {
             $tabs['privileges']['link'] = 'server_privileges.php';
             $tabs['privileges']['args']['checkprivsdb'] = $this->_db;
             $tabs['privileges']['args']['checkprivstable'] = $this->_table;
@@ -343,7 +353,7 @@ class PMA_Menu
         /**
          * Don't display "Operations" for views and information_schema
          */
-        if (! $tbl_is_view && ! $db_is_information_schema) {
+        if (! $tbl_is_view && ! $db_is_system_schema) {
             $tabs['operation']['icon'] = 'b_tblops.png';
             $tabs['operation']['link'] = 'tbl_operations.php';
             $tabs['operation']['text'] = __('Operations');
@@ -353,7 +363,7 @@ class PMA_Menu
             $tabs['tracking']['text'] = __('Tracking');
             $tabs['tracking']['link'] = 'tbl_tracking.php';
         }
-        if (! $db_is_information_schema
+        if (! $db_is_system_schema
             && ! PMA_DRIZZLE
             && PMA_Util::currentUserHasPrivilege(
                 'TRIGGER',
@@ -370,7 +380,7 @@ class PMA_Menu
         /**
          * Views support a limited number of operations
          */
-        if ($tbl_is_view && ! $db_is_information_schema) {
+        if ($tbl_is_view && ! $db_is_system_schema) {
             $tabs['operation']['icon'] = 'b_tblops.png';
             $tabs['operation']['link'] = 'view_operations.php';
             $tabs['operation']['text'] = __('Operations');
@@ -386,9 +396,11 @@ class PMA_Menu
      */
     private function _getDbTabs()
     {
-        $db_is_information_schema = $GLOBALS['dbi']->isSystemSchema($this->_db);
+        $db_is_system_schema = $GLOBALS['dbi']->isSystemSchema($this->_db);
         $num_tables = count($GLOBALS['dbi']->getTables($this->_db));
         $is_superuser = $GLOBALS['dbi']->isSuperuser();
+        $isCreateOrGrantUser = $GLOBALS['dbi']->isUserType('grant')
+            || $GLOBALS['dbi']->isUserType('create');
 
         /**
          * Gets the relation settings
@@ -426,7 +438,7 @@ class PMA_Menu
             $tabs['export']['warning'] = __('Database seems to be empty!');
         }
 
-        if (! $db_is_information_schema) {
+        if (! $db_is_system_schema) {
             $tabs['import']['link'] = 'db_import.php';
             $tabs['import']['text'] = __('Import');
             $tabs['import']['icon'] = 'b_import.png';
@@ -435,7 +447,7 @@ class PMA_Menu
             $tabs['operation']['text'] = __('Operations');
             $tabs['operation']['icon'] = 'b_tblops.png';
 
-            if ($is_superuser && ! PMA_DRIZZLE) {
+            if (($is_superuser || $isCreateOrGrantUser) && ! PMA_DRIZZLE) {
                 $tabs['privileges']['link'] = 'server_privileges.php';
                 $tabs['privileges']['args']['checkprivsdb'] = $this->_db;
                 // stay on database view
@@ -448,8 +460,7 @@ class PMA_Menu
                 $tabs['routines']['text'] = __('Routines');
                 $tabs['routines']['icon'] = 'b_routines.png';
             }
-            if (PMA_MYSQL_INT_VERSION >= 50106
-                && ! PMA_DRIZZLE
+            if (! PMA_DRIZZLE
                 && PMA_Util::currentUserHasPrivilege('EVENT', $this->_db)
             ) {
                 $tabs['events']['link'] = 'db_events.php';
@@ -471,12 +482,21 @@ class PMA_Menu
             $tabs['tracking']['link'] = 'db_tracking.php';
         }
 
-        if (! $db_is_information_schema && $cfgRelation['designerwork']) {
+        if (! $db_is_system_schema) {
             $tabs['designer']['text'] = __('Designer');
             $tabs['designer']['icon'] = 'b_relations.png';
-            $tabs['designer']['link'] = 'pmd_general.php';
+            $tabs['designer']['link'] = 'db_designer.php';
+            $tabs['designer']['id'] = 'designer_tab';
         }
 
+        if (! $db_is_system_schema
+            && isset($cfgRelation['central_columnswork'])
+            && $cfgRelation['central_columnswork']
+        ) {
+            $tabs['central_columns']['text'] = __('Central columns');
+            $tabs['central_columns']['icon'] = 'centralColumns.png';
+            $tabs['central_columns']['link'] = 'db_central_columns.php';
+        }
         return $tabs;
     }
 
@@ -487,18 +507,25 @@ class PMA_Menu
      */
     private function _getServerTabs()
     {
-        $is_superuser = isset($GLOBALS['dbi']) && $GLOBALS['dbi']->isSuperuser();
+        $is_superuser = $GLOBALS['dbi']->isSuperuser();
+        $isCreateOrGrantUser = $GLOBALS['dbi']->isUserType('grant')
+            || $GLOBALS['dbi']->isUserType('create');
         $binary_logs = null;
         $notDrizzle = ! defined('PMA_DRIZZLE')
             || (defined('PMA_DRIZZLE') && ! PMA_DRIZZLE);
-        if (isset($GLOBALS['dbi']) && $notDrizzle) {
-            $binary_logs = $GLOBALS['dbi']->fetchResult(
-                'SHOW MASTER LOGS',
-                'Log_name',
-                null,
-                null,
-                PMA_DatabaseInterface::QUERY_STORE
-            );
+        if ($notDrizzle) {
+            if (PMA_Util::cacheExists('binary_logs')) {
+                $binary_logs = PMA_Util::cacheGet('binary_logs');
+            } else {
+                $binary_logs = $GLOBALS['dbi']->fetchResult(
+                    'SHOW MASTER LOGS',
+                    'Log_name',
+                    null,
+                    null,
+                    PMA_DatabaseInterface::QUERY_STORE
+                );
+                PMA_Util::cacheSet('binary_logs', $binary_logs);
+            }
         }
 
         $tabs = array();
@@ -521,11 +548,12 @@ class PMA_Menu
                 'server_status_advisor.php',
                 'server_status_monitor.php',
                 'server_status_queries.php',
-                'server_status_variables.php'
+                'server_status_variables.php',
+                'server_status_processes.php'
             )
         );
 
-        if ($is_superuser && ! PMA_DRIZZLE) {
+        if (($is_superuser || $isCreateOrGrantUser) && ! PMA_DRIZZLE) {
             $tabs['rights']['icon'] = 's_rights.png';
             $tabs['rights']['link'] = 'server_privileges.php';
             $tabs['rights']['text'] = __('Users');
@@ -583,6 +611,19 @@ class PMA_Menu
         }
         return $tabs;
     }
+
+    /**
+     * Set current table
+     *
+     * @param string $table Current table
+     *
+     * @return $this
+     */
+    public function setTable($table)
+    {
+        $this->_table = $table;
+        return $this;
+    }
 }
 
 ?>
