@@ -1,13 +1,16 @@
 <?php
 /* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
+ * Tracking changes on databases, tables and views
  *
  * @package PhpMyAdmin
  */
+if (! defined('PHPMYADMIN')) {
+    exit;
+}
 
 /**
  * This class tracks changes on databases, tables and views.
- * For more information please see phpMyAdmin/Documentation.html
  *
  * @package PhpMyAdmin
  *
@@ -20,84 +23,18 @@ class PMA_Tracker
      */
     static protected $enabled = false;
 
-    /**
-     * Defines the internal PMA table which contains tracking data.
-     *
-     * @access  protected
-     * @var string
-     */
-    static protected $pma_table;
-
-    /**
-     * Defines the usage of DROP TABLE statment in SQL dumps.
-     *
-     * @access protected
-     * @var boolean
-     */
-    static protected $add_drop_table;
-
-    /**
-     * Defines the usage of DROP VIEW statment in SQL dumps.
-     *
-     * @access protected
-     * @var boolean
-     */
-    static protected $add_drop_view;
-
-    /**
-     * Defines the usage of DROP DATABASE statment in SQL dumps.
-     *
-     * @access protected
-     * @var boolean
-     */
-    static protected $add_drop_database;
-
-    /**
-     * Defines auto-creation of tracking versions.
-     *
-     * @var boolean
-     */
-    static protected $version_auto_create;
-
-    /**
-     * Defines the default set of tracked statements.
-     *
-     * @var string
-     */
-    static protected $default_tracking_set;
-
     /**
      * Flags copied from `tracking` column definition in `pma_tracking` table.
      * Used for column type conversion in Drizzle.
      *
      * @var array
      */
-    static private $tracking_set_flags = array('UPDATE','REPLACE','INSERT','DELETE','TRUNCATE','CREATE DATABASE',
-            'ALTER DATABASE','DROP DATABASE','CREATE TABLE','ALTER TABLE','RENAME TABLE','DROP TABLE','CREATE INDEX',
-            'DROP INDEX','CREATE VIEW','ALTER VIEW','DROP VIEW');
-
-    /**
-     * Initializes settings. See phpMyAdmin/Documentation.html.
-     *
-     * @static
-     *
-     * @return nothing
-     */
-    static protected function init()
-    {
-        self::$pma_table = PMA_backquote($GLOBALS['cfg']['Server']['pmadb']) .".".
-                           PMA_backquote($GLOBALS['cfg']['Server']['tracking']);
-
-        self::$add_drop_table = $GLOBALS['cfg']['Server']['tracking_add_drop_table'];
-
-        self::$add_drop_view = $GLOBALS['cfg']['Server']['tracking_add_drop_view'];
-
-        self::$add_drop_database = $GLOBALS['cfg']['Server']['tracking_add_drop_database'];
-
-        self::$default_tracking_set = $GLOBALS['cfg']['Server']['tracking_default_statements'];
-
-        self::$version_auto_create = $GLOBALS['cfg']['Server']['tracking_version_auto_create'];
-    }
+    static private $_tracking_set_flags = array(
+        'UPDATE','REPLACE','INSERT','DELETE','TRUNCATE','CREATE DATABASE',
+        'ALTER DATABASE','DROP DATABASE','CREATE TABLE','ALTER TABLE',
+        'RENAME TABLE','DROP TABLE','CREATE INDEX','DROP INDEX',
+        'CREATE VIEW','ALTER VIEW','DROP VIEW'
+    );
 
     /**
      * Actually enables tracking. This needs to be done after all
@@ -105,7 +42,7 @@ class PMA_Tracker
      *
      * @static
      *
-     * @return nothing
+     * @return void
      */
     static public function enable()
     {
@@ -124,7 +61,9 @@ class PMA_Tracker
         if (! self::$enabled) {
             return false;
         }
-        /* We need to avoid attempt to track any queries from PMA_getRelationsParam */
+        /* We need to avoid attempt to track any queries
+         * from PMA_getRelationsParam
+         */
         self::$enabled = false;
         $cfgRelation = PMA_getRelationsParam();
         /* Restore original state */
@@ -132,9 +71,9 @@ class PMA_Tracker
         if (! $cfgRelation['trackingwork']) {
             return false;
         }
-        self::init();
 
-        if (isset(self::$pma_table)) {
+        $pma_table = self::_getTrackingTable();
+        if (isset($pma_table)) {
             return true;
         } else {
             return false;
@@ -152,7 +91,7 @@ class PMA_Tracker
      */
     static protected function getTableName($string)
     {
-        if (strstr($string, '.')) {
+        if (/*overload*/mb_strstr($string, '.')) {
             $temp = explode('.', $string);
             $tablename = $temp[1];
         } else {
@@ -185,7 +124,9 @@ class PMA_Tracker
         if (! self::$enabled) {
             return false;
         }
-        /* We need to avoid attempt to track any queries from PMA_getRelationsParam */
+        /* We need to avoid attempt to track any queries
+         * from PMA_getRelationsParam
+         */
         self::$enabled = false;
         $cfgRelation = PMA_getRelationsParam();
         /* Restore original state */
@@ -194,12 +135,12 @@ class PMA_Tracker
             return false;
         }
 
-        $sql_query = " SELECT tracking_active FROM " . self::$pma_table .
-        " WHERE db_name = '" . PMA_sqlAddSlashes($dbname) . "' " .
-        " AND table_name = '" . PMA_sqlAddSlashes($tablename) . "' " .
+        $sql_query = " SELECT tracking_active FROM " . self::_getTrackingTable() .
+        " WHERE db_name = '" . PMA_Util::sqlAddSlashes($dbname) . "' " .
+        " AND table_name = '" . PMA_Util::sqlAddSlashes($tablename) . "' " .
         " ORDER BY version DESC";
 
-        $row = PMA_DBI_fetch_array(PMA_query_as_controluser($sql_query));
+        $row = $GLOBALS['dbi']->fetchArray(PMA_queryAsControlUser($sql_query));
 
         if (isset($row['tracking_active']) && $row['tracking_active'] == 1) {
             return true;
@@ -234,15 +175,27 @@ class PMA_Tracker
      *
      * @return int result of version insertion
      */
-    static public function createVersion($dbname, $tablename, $version, $tracking_set = '', $is_view = false)
-    {
-        global $sql_backquotes;
+    static public function createVersion($dbname, $tablename, $version,
+        $tracking_set = '', $is_view = false
+    ) {
+        global $sql_backquotes, $export_type;
 
         if ($tracking_set == '') {
-            $tracking_set = self::$default_tracking_set;
+            $tracking_set
+                = $GLOBALS['cfg']['Server']['tracking_default_statements'];
         }
 
-        include_once './libraries/export/sql.php';
+        // get Export SQL instance
+        include_once "libraries/plugin_interface.lib.php";
+        $export_sql_plugin = PMA_getPlugin(
+            "export",
+            "sql",
+            'libraries/plugins/export/',
+            array(
+                'export_type' => $export_type,
+                'single_table' => false,
+            )
+        );
 
         $sql_backquotes = true;
 
@@ -250,15 +203,15 @@ class PMA_Tracker
 
         // Get data definition snapshot of table
 
-        $columns = PMA_DBI_get_columns($dbname, $tablename, null, true);
+        $columns = $GLOBALS['dbi']->getColumns($dbname, $tablename, null, true);
         // int indices to reduce size
         $columns = array_values($columns);
         // remove Privileges to reduce size
-        for ($i = 0; $i < count($columns); $i++) {
+        for ($i = 0, $nb = count($columns); $i < $nb; $i++) {
             unset($columns[$i]['Privileges']);
         }
 
-        $indexes = PMA_DBI_get_table_indexes($dbname, $tablename);
+        $indexes = $GLOBALS['dbi']->getTableIndexes($dbname, $tablename);
 
         $snapshot = array('COLUMNS' => $columns, 'INDEXES' => $indexes);
         $snapshot = serialize($snapshot);
@@ -268,24 +221,28 @@ class PMA_Tracker
 
         $create_sql  = "";
 
-        if (self::$add_drop_table == true && $is_view == false) {
-            $create_sql .= self::getLogComment() .
-                           'DROP TABLE IF EXISTS ' . PMA_backquote($tablename) . ";\n";
+        if ($GLOBALS['cfg']['Server']['tracking_add_drop_table'] == true
+            && $is_view == false
+        ) {
+            $create_sql .= self::getLogComment()
+                . 'DROP TABLE IF EXISTS ' . PMA_Util::backquote($tablename) . ";\n";
 
         }
 
-        if (self::$add_drop_view == true && $is_view == true) {
-            $create_sql .= self::getLogComment() .
-                           'DROP VIEW IF EXISTS ' . PMA_backquote($tablename) . ";\n";
+        if ($GLOBALS['cfg']['Server']['tracking_add_drop_view'] == true
+            && $is_view == true
+        ) {
+            $create_sql .= self::getLogComment()
+                . 'DROP VIEW IF EXISTS ' . PMA_Util::backquote($tablename) . ";\n";
         }
 
         $create_sql .= self::getLogComment() .
-                       PMA_getTableDef($dbname, $tablename, "\n", "");
+            $export_sql_plugin->getTableDef($dbname, $tablename, "\n", "");
 
         // Save version
 
         $sql_query = "/*NOTRACK*/\n" .
-        "INSERT INTO" . self::$pma_table . " (" .
+        "INSERT INTO " . self::_getTrackingTable() . " (" .
         "db_name, " .
         "table_name, " .
         "version, " .
@@ -297,17 +254,18 @@ class PMA_Tracker
         "tracking " .
         ") " .
         "values (
-        '" . PMA_sqlAddSlashes($dbname) . "',
-        '" . PMA_sqlAddSlashes($tablename) . "',
-        '" . PMA_sqlAddSlashes($version) . "',
-        '" . PMA_sqlAddSlashes($date) . "',
-        '" . PMA_sqlAddSlashes($date) . "',
-        '" . PMA_sqlAddSlashes($snapshot) . "',
-        '" . PMA_sqlAddSlashes($create_sql) . "',
-        '" . PMA_sqlAddSlashes("\n") . "',
-        '" . PMA_sqlAddSlashes(self::transformTrackingSet($tracking_set)) . "' )";
+        '" . PMA_Util::sqlAddSlashes($dbname) . "',
+        '" . PMA_Util::sqlAddSlashes($tablename) . "',
+        '" . PMA_Util::sqlAddSlashes($version) . "',
+        '" . PMA_Util::sqlAddSlashes($date) . "',
+        '" . PMA_Util::sqlAddSlashes($date) . "',
+        '" . PMA_Util::sqlAddSlashes($snapshot) . "',
+        '" . PMA_Util::sqlAddSlashes($create_sql) . "',
+        '" . PMA_Util::sqlAddSlashes("\n") . "',
+        '" . PMA_Util::sqlAddSlashes(self::_transformTrackingSet($tracking_set))
+        . "' )";
 
-        $result = PMA_query_as_controluser($sql_query);
+        $result = PMA_queryAsControlUser($sql_query);
 
         if ($result) {
             // Deactivate previous version
@@ -330,9 +288,13 @@ class PMA_Tracker
      */
     static public function deleteTracking($dbname, $tablename)
     {
-        $sql_query = "/*NOTRACK*/\n" .
-        "DELETE FROM " . self::$pma_table . " WHERE `db_name` = '" . PMA_sqlAddSlashes($dbname) . "' AND `table_name` = '" . PMA_sqlAddSlashes($tablename) . "'";
-        $result = PMA_query_as_controluser($sql_query);
+        $sql_query = "/*NOTRACK*/\n"
+            . "DELETE FROM " . self::_getTrackingTable()
+            . " WHERE `db_name` = '"
+            . PMA_Util::sqlAddSlashes($dbname) . "'"
+            . " AND `table_name` = '"
+            . PMA_Util::sqlAddSlashes($tablename) . "'";
+        $result = PMA_queryAsControlUser($sql_query);
 
         return $result;
     }
@@ -350,28 +312,28 @@ class PMA_Tracker
      *
      * @return int result of version insertion
      */
-    static public function createDatabaseVersion($dbname, $version, $query, $tracking_set = 'CREATE DATABASE,ALTER DATABASE,DROP DATABASE')
-    {
+    static public function createDatabaseVersion($dbname, $version, $query,
+        $tracking_set = 'CREATE DATABASE,ALTER DATABASE,DROP DATABASE'
+    ) {
         $date = date('Y-m-d H:i:s');
 
         if ($tracking_set == '') {
-            $tracking_set = self::$default_tracking_set;
+            $tracking_set
+                = $GLOBALS['cfg']['Server']['tracking_default_statements'];
         }
 
-        include_once './libraries/export/sql.php';
-
         $create_sql  = "";
 
-        if (self::$add_drop_database == true) {
-            $create_sql .= self::getLogComment() .
-                           'DROP DATABASE IF EXISTS ' . PMA_backquote($dbname) . ";\n";
+        if ($GLOBALS['cfg']['Server']['tracking_add_drop_database'] == true) {
+            $create_sql .= self::getLogComment()
+                . 'DROP DATABASE IF EXISTS ' . PMA_Util::backquote($dbname) . ";\n";
         }
 
         $create_sql .= self::getLogComment() . $query;
 
         // Save version
         $sql_query = "/*NOTRACK*/\n" .
-        "INSERT INTO" . self::$pma_table . " (" .
+        "INSERT INTO " . self::_getTrackingTable() . " (" .
         "db_name, " .
         "table_name, " .
         "version, " .
@@ -383,17 +345,18 @@ class PMA_Tracker
         "tracking " .
         ") " .
         "values (
-        '" . PMA_sqlAddSlashes($dbname) . "',
-        '" . PMA_sqlAddSlashes('') . "',
-        '" . PMA_sqlAddSlashes($version) . "',
-        '" . PMA_sqlAddSlashes($date) . "',
-        '" . PMA_sqlAddSlashes($date) . "',
-        '" . PMA_sqlAddSlashes('') . "',
-        '" . PMA_sqlAddSlashes($create_sql) . "',
-        '" . PMA_sqlAddSlashes("\n") . "',
-        '" . PMA_sqlAddSlashes(self::transformTrackingSet($tracking_set)) . "' )";
+        '" . PMA_Util::sqlAddSlashes($dbname) . "',
+        '" . PMA_Util::sqlAddSlashes('') . "',
+        '" . PMA_Util::sqlAddSlashes($version) . "',
+        '" . PMA_Util::sqlAddSlashes($date) . "',
+        '" . PMA_Util::sqlAddSlashes($date) . "',
+        '" . PMA_Util::sqlAddSlashes('') . "',
+        '" . PMA_Util::sqlAddSlashes($create_sql) . "',
+        '" . PMA_Util::sqlAddSlashes("\n") . "',
+        '" . PMA_Util::sqlAddSlashes(self::_transformTrackingSet($tracking_set))
+        . "' )";
 
-        $result = PMA_query_as_controluser($sql_query);
+        $result = PMA_queryAsControlUser($sql_query);
 
         return $result;
     }
@@ -412,15 +375,17 @@ class PMA_Tracker
      *
      * @return int result of SQL query
      */
-    static private function _changeTracking($dbname, $tablename, $version, $new_state)
-    {
-        $sql_query = " UPDATE " . self::$pma_table .
-        " SET `tracking_active` = '" . $new_state . "' " .
-        " WHERE `db_name` = '" . PMA_sqlAddSlashes($dbname) . "' " .
-        " AND `table_name` = '" . PMA_sqlAddSlashes($tablename) . "' " .
-        " AND `version` = '" . PMA_sqlAddSlashes($version) . "' ";
+    static private function _changeTracking($dbname, $tablename,
+        $version, $new_state
+    ) {
 
-        $result = PMA_query_as_controluser($sql_query);
+        $sql_query = " UPDATE " . self::_getTrackingTable() .
+        " SET `tracking_active` = '" . $new_state . "' " .
+        " WHERE `db_name` = '" . PMA_Util::sqlAddSlashes($dbname) . "' " .
+        " AND `table_name` = '" . PMA_Util::sqlAddSlashes($tablename) . "' " .
+        " AND `version` = '" . PMA_Util::sqlAddSlashes($version) . "' ";
+
+        $result = PMA_queryAsControlUser($sql_query);
 
         return $result;
     }
@@ -438,8 +403,9 @@ class PMA_Tracker
      *
      * @return bool result of change
      */
-    static public function changeTrackingData($dbname, $tablename, $version, $type, $new_data)
-    {
+    static public function changeTrackingData($dbname, $tablename,
+        $version, $type, $new_data
+    ) {
         if ($type == 'DDL') {
             $save_to = 'schema_sql';
         } elseif ($type == 'DML') {
@@ -453,19 +419,19 @@ class PMA_Tracker
         if (is_array($new_data)) {
             foreach ($new_data as $data) {
                 $new_data_processed .= '# log ' . $date . ' ' . $data['username']
-                    . PMA_sqlAddSlashes($data['statement']) . "\n";
+                    . PMA_Util::sqlAddSlashes($data['statement']) . "\n";
             }
         } else {
             $new_data_processed = $new_data;
         }
 
-        $sql_query = " UPDATE " . self::$pma_table .
+        $sql_query = " UPDATE " . self::_getTrackingTable() .
         " SET `" . $save_to . "` = '" . $new_data_processed . "' " .
-        " WHERE `db_name` = '" . PMA_sqlAddSlashes($dbname) . "' " .
-        " AND `table_name` = '" . PMA_sqlAddSlashes($tablename) . "' " .
-        " AND `version` = '" . PMA_sqlAddSlashes($version) . "' ";
+        " WHERE `db_name` = '" . PMA_Util::sqlAddSlashes($dbname) . "' " .
+        " AND `table_name` = '" . PMA_Util::sqlAddSlashes($tablename) . "' " .
+        " AND `version` = '" . PMA_Util::sqlAddSlashes($version) . "' ";
 
-        $result = PMA_query_as_controluser($sql_query);
+        $result = PMA_queryAsControlUser($sql_query);
 
         return $result;
     }
@@ -518,16 +484,20 @@ class PMA_Tracker
      */
     static public function getVersion($dbname, $tablename, $statement = null)
     {
-        $sql_query = " SELECT MAX(version) FROM " . self::$pma_table .
-        " WHERE `db_name` = '" . PMA_sqlAddSlashes($dbname) . "' " .
-        " AND `table_name` = '" . PMA_sqlAddSlashes($tablename) . "' ";
+        $sql_query = " SELECT MAX(version) FROM " . self::_getTrackingTable() .
+        " WHERE `db_name` = '" . PMA_Util::sqlAddSlashes($dbname) . "' " .
+        " AND `table_name` = '" . PMA_Util::sqlAddSlashes($tablename) . "' ";
 
         if ($statement != "") {
-            $sql_query .= PMA_DRIZZLE
-                ? ' AND tracking & ' . self::transformTrackingSet($statement) . ' <> 0'
-                : " AND FIND_IN_SET('" . $statement . "',tracking) > 0" ;
+            if (PMA_DRIZZLE) {
+                $sql_query .= ' AND tracking & '
+                    . self::_transformTrackingSet($statement) . ' <> 0';
+            } else {
+                $sql_query .= " AND FIND_IN_SET('"
+                    . $statement . "',tracking) > 0" ;
+            }
         }
-        $row = PMA_DBI_fetch_array(PMA_query_as_controluser($sql_query));
+        $row = $GLOBALS['dbi']->fetchArray(PMA_queryAsControlUser($sql_query));
         return isset($row[0])
             ? $row[0]
             : -1;
@@ -543,22 +513,21 @@ class PMA_Tracker
      *
      * @static
      *
-     * @return mixed record DDM log, DDL log, structure snapshot, tracked statements.
+     * @return mixed record DDM log, DDL log, structure snapshot, tracked
+     *         statements.
      */
     static public function getTrackedData($dbname, $tablename, $version)
     {
-        if (! isset(self::$pma_table)) {
-            self::init();
-        }
-        $sql_query = " SELECT * FROM " . self::$pma_table .
-            " WHERE `db_name` = '" . PMA_sqlAddSlashes($dbname) . "' ";
+        $sql_query = " SELECT * FROM " . self::_getTrackingTable() .
+            " WHERE `db_name` = '" . PMA_Util::sqlAddSlashes($dbname) . "' ";
         if (! empty($tablename)) {
-            $sql_query .= " AND `table_name` = '" . PMA_sqlAddSlashes($tablename) ."' ";
+            $sql_query .= " AND `table_name` = '"
+                . PMA_Util::sqlAddSlashes($tablename) . "' ";
         }
-        $sql_query .= " AND `version` = '" . PMA_sqlAddSlashes($version) ."' ".
-                     " ORDER BY `version` DESC LIMIT 1";
+        $sql_query .= " AND `version` = '" . PMA_Util::sqlAddSlashes($version)
+            . "' " . " ORDER BY `version` DESC LIMIT 1";
 
-        $mixed = PMA_DBI_fetch_assoc(PMA_query_as_controluser($sql_query));
+        $mixed = $GLOBALS['dbi']->fetchAssoc(PMA_queryAsControlUser($sql_query));
 
         // Parse log
         $log_schema_entries = explode('# log ',  $mixed['schema_sql']);
@@ -573,12 +542,14 @@ class PMA_Tracker
         // For each log entry we want to get date, username and statement
         foreach ($log_schema_entries as $log_entry) {
             if (trim($log_entry) != '') {
-                $date      = substr($log_entry, 0, 19);
-                $username  = substr($log_entry, 20, strpos($log_entry, "\n") - 20);
+                $date      = /*overload*/mb_substr($log_entry, 0, 19);
+                $username  = /*overload*/mb_substr(
+                    $log_entry, 20, /*overload*/mb_strpos($log_entry, "\n") - 20
+                );
                 if ($i == 0) {
                     $ddl_date_from = $date;
                 }
-                $statement = rtrim(strstr($log_entry, "\n"));
+                $statement = rtrim(/*overload*/mb_strstr($log_entry, "\n"));
 
                 $ddlog[] = array( 'date' => $date,
                                   'username'=> $username,
@@ -588,7 +559,7 @@ class PMA_Tracker
         }
 
         $date_from = $ddl_date_from;
-        $date_to   = $ddl_date_to = $date;
+        $ddl_date_to = $date;
 
         $dml_date_from = $date_from;
 
@@ -599,12 +570,14 @@ class PMA_Tracker
         // For each log entry we want to get date, username and statement
         foreach ($log_data_entries as $log_entry) {
             if (trim($log_entry) != '') {
-                $date      = substr($log_entry, 0, 19);
-                $username  = substr($log_entry, 20, strpos($log_entry, "\n") - 20);
+                $date      = /*overload*/mb_substr($log_entry, 0, 19);
+                $username  = /*overload*/mb_substr(
+                    $log_entry, 20, /*overload*/mb_strpos($log_entry, "\n") - 20
+                );
                 if ($i == 0) {
                     $dml_date_from = $date;
                 }
-                $statement = rtrim(strstr($log_entry, "\n"));
+                $statement = rtrim(/*overload*/mb_strstr($log_entry, "\n"));
 
                 $dmlog[] = array( 'date' => $date,
                                   'username' => $username,
@@ -616,6 +589,7 @@ class PMA_Tracker
         $dml_date_to = $date;
 
         // Define begin and end of date range for both logs
+        $data = array();
         if (strtotime($ddl_date_from) <= strtotime($dml_date_from)) {
             $data['date_from'] = $ddl_date_from;
         } else {
@@ -628,7 +602,7 @@ class PMA_Tracker
         }
         $data['ddlog']           = $ddlog;
         $data['dmlog']           = $dmlog;
-        $data['tracking']        = self::transformTrackingSet($mixed['tracking']);
+        $data['tracking']        = self::_transformTrackingSet($mixed['tracking']);
         $data['schema_snapshot'] = $mixed['schema_snapshot'];
 
         return $data;
@@ -652,7 +626,6 @@ class PMA_Tracker
      */
     static public function parseQuery($query)
     {
-
         // Usage of PMA_SQP does not work here
         //
         // require_once("libraries/sqlparser.lib.php");
@@ -667,11 +640,11 @@ class PMA_Tracker
 
         $tokens = explode(" ", $query);
         foreach ($tokens as $key => $value) {
-            $tokens[$key] = strtoupper($value);
+            $tokens[$key] = /*overload*/mb_strtoupper($value);
         }
 
         // Parse USE statement, need it for SQL dump imports
-        if (substr($query, 0, 4) == 'USE ') {
+        if (/*overload*/mb_substr($query, 0, 4) == 'USE ') {
             $prefix = explode('USE ', $query);
             $GLOBALS['db'] = self::getTableName($prefix[1]);
         }
@@ -680,7 +653,8 @@ class PMA_Tracker
          * DDL statements
          */
 
-        $result['type']         = 'DDL';
+        $result         = array();
+        $result['type'] = 'DDL';
 
         // Parse CREATE VIEW statement
         if (in_array('CREATE', $tokens) == true
@@ -691,7 +665,9 @@ class PMA_Tracker
 
             $index = array_search('VIEW', $tokens);
 
-            $result['tablename'] = strtolower(self::getTableName($tokens[$index + 1]));
+            $result['tablename'] = /*overload*/mb_strtolower(
+                self::getTableName($tokens[$index + 1])
+            );
         }
 
         // Parse ALTER VIEW statement
@@ -704,24 +680,26 @@ class PMA_Tracker
 
             $index = array_search('VIEW', $tokens);
 
-            $result['tablename'] = strtolower(self::getTableName($tokens[$index + 1]));
+            $result['tablename'] = /*overload*/mb_strtolower(
+                self::getTableName($tokens[$index + 1])
+            );
         }
 
         // Parse DROP VIEW statement
-        if (! isset($result['identifier']) && substr($query, 0, 10) == 'DROP VIEW ') {
+        if (! isset($result['identifier'])
+            && substr($query, 0, 10) == 'DROP VIEW '
+        ) {
             $result['identifier'] = 'DROP VIEW';
 
             $prefix  = explode('DROP VIEW ', $query);
-            $str = strstr($prefix[1], 'IF EXISTS');
-
-            if ($str == false ) {
-                $str = $prefix[1];
-            }
+            $str = str_replace('IF EXISTS', '', $prefix[1]);
             $result['tablename'] = self::getTableName($str);
         }
 
         // Parse CREATE DATABASE statement
-        if (! isset($result['identifier']) && substr($query, 0, 15) == 'CREATE DATABASE') {
+        if (! isset($result['identifier'])
+            && substr($query, 0, 15) == 'CREATE DATABASE'
+        ) {
             $result['identifier'] = 'CREATE DATABASE';
             $str = str_replace('CREATE DATABASE', '', $query);
             $str = str_replace('IF NOT EXISTS', '', $str);
@@ -733,13 +711,17 @@ class PMA_Tracker
         }
 
         // Parse ALTER DATABASE statement
-        if (! isset($result['identifier']) && substr($query, 0, 14) == 'ALTER DATABASE') {
+        if (! isset($result['identifier'])
+            && substr($query, 0, 14) == 'ALTER DATABASE'
+        ) {
             $result['identifier'] = 'ALTER DATABASE';
             $result['tablename'] = '';
         }
 
         // Parse DROP DATABASE statement
-        if (! isset($result['identifier']) && substr($query, 0, 13) == 'DROP DATABASE') {
+        if (! isset($result['identifier'])
+            && substr($query, 0, 13) == 'DROP DATABASE'
+        ) {
             $result['identifier'] = 'DROP DATABASE';
             $str = str_replace('DROP DATABASE', '', $query);
             $str = str_replace('IF EXISTS', '', $str);
@@ -748,7 +730,9 @@ class PMA_Tracker
         }
 
         // Parse CREATE TABLE statement
-        if (! isset($result['identifier']) && substr($query, 0, 12) == 'CREATE TABLE' ) {
+        if (! isset($result['identifier'])
+            && substr($query, 0, 12) == 'CREATE TABLE'
+        ) {
             $result['identifier'] = 'CREATE TABLE';
             $query   = str_replace('IF NOT EXISTS', '', $query);
             $prefix  = explode('CREATE TABLE ', $query);
@@ -757,7 +741,9 @@ class PMA_Tracker
         }
 
         // Parse ALTER TABLE statement
-        if (! isset($result['identifier']) && substr($query, 0, 12) == 'ALTER TABLE ') {
+        if (! isset($result['identifier'])
+            && substr($query, 0, 12) == 'ALTER TABLE '
+        ) {
             $result['identifier'] = 'ALTER TABLE';
 
             $prefix  = explode('ALTER TABLE ', $query);
@@ -766,15 +752,13 @@ class PMA_Tracker
         }
 
         // Parse DROP TABLE statement
-        if (! isset($result['identifier']) && substr($query, 0, 11) == 'DROP TABLE ') {
+        if (! isset($result['identifier'])
+            && substr($query, 0, 11) == 'DROP TABLE '
+        ) {
             $result['identifier'] = 'DROP TABLE';
 
             $prefix  = explode('DROP TABLE ', $query);
-            $str = strstr($prefix[1], 'IF EXISTS');
-
-            if ($str == false ) {
-                $str = $prefix[1];
-            }
+            $str = str_replace('IF EXISTS', '', $prefix[1]);
             $result['tablename'] = self::getTableName($str);
         }
 
@@ -791,14 +775,18 @@ class PMA_Tracker
         }
 
         // Parse DROP INDEX statement
-        if (! isset($result['identifier']) && substr($query, 0, 10) == 'DROP INDEX') {
+        if (! isset($result['identifier'])
+            && substr($query, 0, 10) == 'DROP INDEX'
+        ) {
              $result['identifier'] = 'DROP INDEX';
              $prefix = explode('ON ', $query);
              $result['tablename'] = self::getTableName($prefix[1]);
         }
 
         // Parse RENAME TABLE statement
-        if (! isset($result['identifier']) && substr($query, 0, 13) == 'RENAME TABLE ') {
+        if (! isset($result['identifier'])
+            && substr($query, 0, 13) == 'RENAME TABLE '
+        ) {
             $result['identifier'] = 'RENAME TABLE';
             $prefix = explode('RENAME TABLE ', $query);
             $names  = explode(' TO ', $prefix[1]);
@@ -814,7 +802,9 @@ class PMA_Tracker
             $result["type"]       = 'DML';
         }
         // Parse UPDATE statement
-        if (! isset($result['identifier']) && substr($query, 0, 6) == 'UPDATE') {
+        if (! isset($result['identifier'])
+            && substr($query, 0, 6) == 'UPDATE'
+        ) {
             $result['identifier'] = 'UPDATE';
             $prefix  = explode('UPDATE ', $query);
             $suffix  = explode(' ', $prefix[1]);
@@ -822,7 +812,9 @@ class PMA_Tracker
         }
 
         // Parse INSERT INTO statement
-        if (! isset($result['identifier']) && substr($query, 0, 11) == 'INSERT INTO') {
+        if (! isset($result['identifier'])
+            && substr($query, 0, 11) == 'INSERT INTO'
+        ) {
             $result['identifier'] = 'INSERT';
             $prefix  = explode('INSERT INTO', $query);
             $suffix  = explode('(', $prefix[1]);
@@ -830,7 +822,9 @@ class PMA_Tracker
         }
 
         // Parse DELETE statement
-        if (! isset($result['identifier']) && substr($query, 0, 6) == 'DELETE') {
+        if (! isset($result['identifier'])
+            && substr($query, 0, 6) == 'DELETE'
+        ) {
             $result['identifier'] = 'DELETE';
             $prefix  = explode('FROM ', $query);
             $suffix  = explode(' ', $prefix[1]);
@@ -838,7 +832,9 @@ class PMA_Tracker
         }
 
         // Parse TRUNCATE statement
-        if (! isset($result['identifier']) && substr($query, 0, 8) == 'TRUNCATE') {
+        if (! isset($result['identifier'])
+            && substr($query, 0, 8) == 'TRUNCATE'
+        ) {
             $result['identifier'] = 'TRUNCATE';
             $prefix  = explode('TRUNCATE', $query);
             $result['tablename'] = self::getTableName($prefix[1]);
@@ -855,12 +851,12 @@ class PMA_Tracker
      *
      * @static
      *
-     * @return nothing
+     * @return void
      */
     static public function handleQuery($query)
     {
         // If query is marked as untouchable, leave
-        if (strstr($query, "/*NOTRACK*/")) {
+        if (/*overload*/mb_strstr($query, "/*NOTRACK*/")) {
             return;
         }
 
@@ -871,7 +867,7 @@ class PMA_Tracker
         $result = self::parseQuery($query);
 
         // Get database name
-        $dbname = trim($GLOBALS['db'], '`');
+        $dbname = trim(isset($GLOBALS['db']) ? $GLOBALS['db'] : '', '`');
         // $dbname can be empty, for example when coming from Synchronize
         // and this is a query for the remote server
         if (empty($dbname)) {
@@ -880,10 +876,12 @@ class PMA_Tracker
 
         // If we found a valid statement
         if (isset($result['identifier'])) {
-            $version = self::getVersion($dbname, $result['tablename'], $result['identifier']);
+            $version = self::getVersion(
+                $dbname, $result['tablename'], $result['identifier']
+            );
 
             // If version not exists and auto-creation is enabled
-            if (self::$version_auto_create == true
+            if ($GLOBALS['cfg']['Server']['tracking_version_auto_create'] == true
                 && self::isTracked($dbname, $result['tablename']) == false
                 && $version == -1
             ) {
@@ -894,7 +892,9 @@ class PMA_Tracker
                     self::createVersion($dbname, $result['tablename'], '1');
                     break;
                 case 'CREATE VIEW':
-                    self::createVersion($dbname, $result['tablename'], '1', '', true);
+                    self::createVersion(
+                        $dbname, $result['tablename'], '1', '', true
+                    );
                     break;
                 case 'CREATE DATABASE':
                     self::createDatabaseVersion($dbname, '1', $query);
@@ -914,20 +914,29 @@ class PMA_Tracker
                 $date  = date('Y-m-d H:i:s');
 
                 // Cut off `dbname`. from query
-                $query = preg_replace('/`' . $dbname . '`\s?\./', '', $query);
+                $query = preg_replace(
+                    '/`' . preg_quote($dbname) . '`\s?\./',
+                    '',
+                    $query
+                );
 
                 // Add log information
                 $query = self::getLogComment() . $query ;
 
                 // Mark it as untouchable
-                $sql_query = " /*NOTRACK*/\n" .
-                " UPDATE " . self::$pma_table .
-                " SET " . PMA_backquote($save_to) ." = CONCAT( " . PMA_backquote($save_to) . ",'\n"
-                . PMA_sqlAddSlashes($query) . "') ," . " `date_updated` = '" . $date . "' ";
+                $sql_query = " /*NOTRACK*/\n"
+                    . " UPDATE " . self::_getTrackingTable()
+                    . " SET " . PMA_Util::backquote($save_to)
+                    . " = CONCAT( " . PMA_Util::backquote($save_to) . ",'\n"
+                    . PMA_Util::sqlAddSlashes($query) . "') ,"
+                    . " `date_updated` = '" . $date . "' ";
 
-                // If table was renamed we have to change the tablename attribute in pma_tracking too
+                // If table was renamed we have to change
+                // the tablename attribute in pma_tracking too
                 if ($result['identifier'] == 'RENAME TABLE') {
-                    $sql_query .= ', `table_name` = \'' . PMA_sqlAddSlashes($result['tablename_after_rename']) . '\' ';
+                    $sql_query .= ', `table_name` = \''
+                        . PMA_Util::sqlAddSlashes($result['tablename_after_rename'])
+                        . '\' ';
                 }
 
                 // Save the tracking information only for
@@ -937,11 +946,12 @@ class PMA_Tracker
                 // we want to track
                 $sql_query .=
                 " WHERE FIND_IN_SET('" . $result['identifier'] . "',tracking) > 0" .
-                " AND `db_name` = '" . PMA_sqlAddSlashes($dbname) . "' " .
-                " AND `table_name` = '" . PMA_sqlAddSlashes($result['tablename']) . "' " .
-                " AND `version` = '" . PMA_sqlAddSlashes($version) . "' ";
+                " AND `db_name` = '" . PMA_Util::sqlAddSlashes($dbname) . "' " .
+                " AND `table_name` = '"
+                . PMA_Util::sqlAddSlashes($result['tablename']) . "' " .
+                " AND `version` = '" . PMA_Util::sqlAddSlashes($version) . "' ";
 
-                $result = PMA_query_as_controluser($sql_query);
+                $result = PMA_queryAsControlUser($sql_query);
             }
         }
     }
@@ -951,36 +961,38 @@ class PMA_Tracker
      *
      * Converts int<>string for Drizzle, does nothing for MySQL
      *
-     * @param int|string $tracking_set
+     * @param int|string $tracking_set Set to convert
+     *
      * @return int|string
      */
-    static private function transformTrackingSet($tracking_set)
+    static private function _transformTrackingSet($tracking_set)
     {
         if (!PMA_DRIZZLE) {
             return $tracking_set;
         }
 
         // init conversion array (key 3 doesn't exist in calculated array)
-        if (isset(self::$tracking_set_flags[3])) {
+        if (isset(self::$_tracking_set_flags[3])) {
             // initialize flags
-            $set = self::$tracking_set_flags;
+            $set = self::$_tracking_set_flags;
             $array = array();
-            for ($i = 0; $i < count($set); $i++) {
+            for ($i = 0, $nb = count($set); $i < $nb; $i++) {
                 $flag = 1 << $i;
                 $array[$flag] = $set[$i];
                 $array[$set[$i]] = $flag;
             }
-            self::$tracking_set_flags = $array;
+            self::$_tracking_set_flags = $array;
         }
 
         if (is_numeric($tracking_set)) {
             // int > string conversion
             $aflags = array();
-            // count/2 - conversion table has both int > string and string > int values
-            for ($i = 0; $i < count(self::$tracking_set_flags)/2; $i++) {
+            // count/2 - conversion table has both int > string
+            // and string > int values
+            for ($i = 0, $nb = count(self::$_tracking_set_flags)/2; $i < $nb; $i++) {
                 $flag = 1 << $i;
                 if ($tracking_set & $flag) {
-                    $aflags[] = self::$tracking_set_flags[$flag];
+                    $aflags[] = self::$_tracking_set_flags[$flag];
                 }
             }
             $flags = implode(',', $aflags);
@@ -991,11 +1003,23 @@ class PMA_Tracker
                 if ($strflag == '') {
                     continue;
                 }
-                $flags |= self::$tracking_set_flags[$strflag];
+                $flags |= self::$_tracking_set_flags[$strflag];
             }
         }
 
         return $flags;
     }
+
+    /**
+     * Returns the tracking table
+     *
+     * @return string tracking table
+     */
+    private static function _getTrackingTable()
+    {
+        $cfgRelation = PMA_getRelationsParam();
+        return PMA_Util::backquote($cfgRelation['db'])
+            . '.' . PMA_Util::backquote($cfgRelation['tracking']);
+    }
 }
 ?>
