@@ -18,28 +18,10 @@ if (! defined('PHPMYADMIN')) {
 function PMA_getIndexedColumns()
 {
     $field_cnt      = count($_REQUEST['field_name']);
-    $field_primary  = array();
-    $field_index    = array();
-    $field_unique   = array();
-    $field_fulltext = array();
-    for ($i = 0; $i < $field_cnt; ++$i) {
-        if (isset($_REQUEST['field_key'][$i])
-            && strlen($_REQUEST['field_name'][$i])
-        ) {
-            if ($_REQUEST['field_key'][$i] == 'primary_' . $i) {
-                $field_primary[] = $i;
-            }
-            if ($_REQUEST['field_key'][$i] == 'index_' . $i) {
-                $field_index[]   = $i;
-            }
-            if ($_REQUEST['field_key'][$i] == 'unique_' . $i) {
-                $field_unique[]  = $i;
-            }
-            if ($_REQUEST['field_key'][$i] == 'fulltext_' . $i) {
-                $field_fulltext[]  = $i;
-            }
-        } // end if
-    } // end for
+    $field_primary  = json_decode($_REQUEST['primary_indexes'], true);
+    $field_index    = json_decode($_REQUEST['indexes'], true);
+    $field_unique   = json_decode($_REQUEST['unique_indexes'], true);
+    $field_fulltext = json_decode($_REQUEST['fulltext_indexes'], true);
 
     return array(
         $field_cnt, $field_primary, $field_index, $field_unique,
@@ -73,7 +55,7 @@ function PMA_buildColumnCreationStatement(
 
         $definition = PMA_getStatementPrefix($is_create_tbl) .
                 PMA_Table::generateFieldSpec(
-                    $_REQUEST['field_name'][$i],
+                    trim($_REQUEST['field_name'][$i]),
                     $_REQUEST['field_type'][$i],
                     $i,
                     $_REQUEST['field_length'][$i],
@@ -95,7 +77,6 @@ function PMA_buildColumnCreationStatement(
                     $field_primary
                 );
 
-
         $definition .= PMA_setColumnCreationStatementSuffix($i, $is_create_tbl);
         $definitions[] = $definition;
     } // end for
@@ -146,28 +127,36 @@ function PMA_setColumnCreationStatementSuffix($current_field_num,
 /**
  * Create relevant index statements
  *
- * @param array   $indexed_fields an array of index columns
- * @param string  $index_type     index type that which represents
- *                                the index type of $indexed_fields
- * @param boolean $is_create_tbl  true if requirement is to get the statement
- *                                for table creation
+ * @param array   $index         an array of index columns
+ * @param string  $index_type    index type that which represents
+ *                               the index type of $indexed_fields
+ * @param boolean $is_create_tbl true if requirement is to get the statement
+ *                               for table creation
  *
  * @return array an array of sql statements for indexes
  */
-function PMA_buildIndexStatements($indexed_fields, $index_type,
+function PMA_buildIndexStatements($index, $index_type,
     $is_create_tbl = true
 ) {
     $statement = array();
-    if (!count($indexed_fields)) {
+    if (!count($index)) {
         return $statement;
     }
 
     $fields = array();
-    foreach ($indexed_fields as $field_nr) {
-        $fields[] = PMA_Util::backquote($_REQUEST['field_name'][$field_nr]);
+    foreach ($index['columns'] as $field) {
+        $fields[]
+            = PMA_Util::backquote($_REQUEST['field_name'][$field['col_index']])
+            . (! empty($field['size']) ? '(' . $field['size'] . ')' : '');
     }
     $statement[] = PMA_getStatementPrefix($is_create_tbl)
-        . ' ' . $index_type . ' (' . implode(', ', $fields) . ') ';
+        . ' ' . $index_type
+        . (! empty($index['Key_name']) && $index['Key_name'] != 'PRIMARY' ?
+        PMA_Util::backquote($index['Key_name'])
+        : '')
+        . ' (' . implode(', ', $fields) . ') '
+        . (! empty($index['Index_comment']) ? 'COMMENT '
+        . "'" . $index['Index_comment'] . "' " : '');
     unset($fields);
 
     return $statement;
@@ -190,6 +179,29 @@ function PMA_getStatementPrefix($is_create_tbl = true)
     return $sql_prefix;
 }
 
+/**
+ * Merge index definitions for one type of index 
+ *
+ * @param array   $definitions     the index definitions to merge to
+ * @param boolean $is_create_tbl   true if requirement is to get the statement
+ *                                 for table creation
+ * @param array   $indexed_columns the columns for one type of index
+ * @param string  $index_keyword   the index keyword to use in the definition
+ *
+ * @return array $index_definitions 
+ */
+function PMA_mergeIndexStatements(
+    $definitions, $is_create_tbl, $indexed_columns, $index_keyword
+) {
+    foreach ($indexed_columns as $index) {
+        $statements = PMA_buildIndexStatements(
+            $index, " " . $index_keyword . " ", $is_create_tbl
+        );
+        $definitions = array_merge($definitions, $statements);
+    }
+    return $definitions;
+}
+
 /**
  * Returns sql statement according to the column and index specifications as
  * requested
@@ -201,7 +213,6 @@ function PMA_getStatementPrefix($is_create_tbl = true)
  */
 function PMA_getColumnCreationStatements($is_create_tbl = true)
 {
-    $definitions = array();
     $sql_statement = "";
     list($field_cnt, $field_primary, $field_index,
             $field_unique, $field_fulltext
@@ -210,29 +221,28 @@ function PMA_getColumnCreationStatements($is_create_tbl = true)
         $field_cnt, $field_primary, $is_create_tbl
     );
 
-    // Builds the primary keys statements
+    // Builds the PRIMARY KEY statements
     $primary_key_statements = PMA_buildIndexStatements(
-        $field_primary, " PRIMARY KEY ", $is_create_tbl
+        isset($field_primary[0]) ? $field_primary[0] : array(),
+        " PRIMARY KEY ",
+        $is_create_tbl
     );
     $definitions = array_merge($definitions, $primary_key_statements);
 
-    // Builds the indexes statements
-    $index_statements = PMA_buildIndexStatements(
-        $field_index, " INDEX ", $is_create_tbl
+    // Builds the INDEX statements
+    $definitions = PMA_mergeIndexStatements(
+        $definitions, $is_create_tbl, $field_index, "INDEX"
     );
-    $definitions = array_merge($definitions, $index_statements);
 
-    // Builds the uniques statements
-    $unique_statements = PMA_buildIndexStatements(
-        $field_unique, " UNIQUE ", $is_create_tbl
+    // Builds the UNIQUE statements
+    $definitions = PMA_mergeIndexStatements(
+        $definitions, $is_create_tbl, $field_unique, "UNIQUE"
     );
-    $definitions = array_merge($definitions, $unique_statements);
 
-    // Builds the fulltext statements
-    $fulltext_statements = PMA_buildIndexStatements(
-        $field_fulltext, " FULLTEXT ", $is_create_tbl
+    // Builds the FULLTEXT statements
+    $definitions = PMA_mergeIndexStatements(
+        $definitions, $is_create_tbl, $field_fulltext, "FULLTEXT"
     );
-    $definitions = array_merge($definitions, $fulltext_statements);
 
     if (count($definitions)) {
         $sql_statement = implode(', ', $definitions);
@@ -322,11 +332,15 @@ function PMA_tryColumnCreationQuery($db, $table, $err_url)
     $GLOBALS['dbi']->selectDb($db)
         or PMA_Util::mysqlDie(
             $GLOBALS['dbi']->getError(),
-            'USE ' . PMA_Util::backquote($db), '',
+            'USE ' . PMA_Util::backquote($db), false,
             $err_url
         );
     $sql_query    = 'ALTER TABLE ' .
         PMA_Util::backquote($table) . ' ' . $sql_statement . ';';
+    // If there is a request for SQL previewing.
+    if (isset($_REQUEST['preview_sql'])) {
+        PMA_previewSQL($sql_query);
+    }
     return array($GLOBALS['dbi']->tryQuery($sql_query) , $sql_query);
 }
 ?>
