@@ -361,7 +361,7 @@ class Node_Database extends Node
 
         // Remove hidden items so that they are not displayed in navigation tree
         $cfgRelation = PMA_getRelationsParam();
-        if ($cfgRelation['navwork']) {
+        if (isset($cfgRelation['navwork']) && $cfgRelation['navwork']) {
             $navTable = PMA_Util::backquote($cfgRelation['db'])
                 . "." . PMA_Util::backquote($cfgRelation['navigationhiding']);
             $sqlQuery = "SELECT `item_name` FROM " . $navTable
@@ -652,6 +652,16 @@ class Node_Database extends Node
     {
         $this->_hiddenCount = $count;
     }
+
+    /**
+     * Returns the number of hidden items in this database
+     *
+     * @return int hidden item count
+     */
+    public function getHiddenCount()
+    {
+        return $this->_hiddenCount;
+    }
 }
 
 ?>
