@@ -48,14 +48,33 @@ class Node_Table extends Node_DatabaseChild
             $this->icon  = PMA_Util::getImage('b_browse.png', __('Browse'));
             break;
         }
+        switch($GLOBALS['cfg']['DefaultTabTable']) {
+        case 'tbl_structure.php':
+            $this->title = __('Structure');
+            break;
+        case 'tbl_select.php':
+            $this->title = __('Search');
+            break;
+        case 'tbl_change.php':
+            $this->title = __('Insert');
+            break;
+        case 'tbl_sql.php':
+            $this->title = __('SQL');
+            break;
+        case 'sql.php':
+            $this->title = __('Browse');
+            break;
+        }
         $this->links = array(
             'text' => $GLOBALS['cfg']['DefaultTabTable']
                     . '?server=' . $GLOBALS['server']
                     . '&amp;db=%2$s&amp;table=%1$s'
-                    . '&amp;pos=0&amp;token=' . $GLOBALS['token'],
+                    . '&amp;pos=0&amp;token=' . $_SESSION[' PMA_token '],
             'icon' => $GLOBALS['cfg']['NavigationTreeDefaultTabTable']
                     . '?server=' . $GLOBALS['server']
-                    . '&amp;db=%2$s&amp;table=%1$s&amp;token=' . $GLOBALS['token']
+                    . '&amp;db=%2$s&amp;table=%1$s&amp;token='
+                    . $_SESSION[' PMA_token '],
+            'title' => $this->title
         );
         $this->classes = 'table';
     }
@@ -77,13 +96,22 @@ class Node_Table extends Node_DatabaseChild
         $table  = $this->real_name;
         switch ($type) {
         case 'columns':
-            $db     = PMA_Util::sqlAddSlashes($db);
-            $table  = PMA_Util::sqlAddSlashes($table);
-            $query  = "SELECT COUNT(*) ";
-            $query .= "FROM `INFORMATION_SCHEMA`.`COLUMNS` ";
-            $query .= "WHERE `TABLE_NAME`='$table' ";
-            $query .= "AND `TABLE_SCHEMA`='$db'";
-            $retval = (int)$GLOBALS['dbi']->fetchValue($query);
+            if (! $GLOBALS['cfg']['Server']['DisableIS']) {
+                $db     = PMA_Util::sqlAddSlashes($db);
+                $table  = PMA_Util::sqlAddSlashes($table);
+                $query  = "SELECT COUNT(*) ";
+                $query .= "FROM `INFORMATION_SCHEMA`.`COLUMNS` ";
+                $query .= "WHERE `TABLE_NAME`='$table' ";
+                $query .= "AND `TABLE_SCHEMA`='$db'";
+                $retval = (int)$GLOBALS['dbi']->fetchValue($query);
+            } else {
+                $db     = PMA_Util::backquote($db);
+                $table  = PMA_Util::backquote($table);
+                $query  = "SHOW COLUMNS FROM $table FROM $db";
+                $retval = (int)$GLOBALS['dbi']->numRows(
+                    $GLOBALS['dbi']->tryQuery($query)
+                );
+            }
             break;
         case 'indexes':
             $db     = PMA_Util::backquote($db);
@@ -94,13 +122,24 @@ class Node_Table extends Node_DatabaseChild
             );
             break;
         case 'triggers':
-            $db     = PMA_Util::sqlAddSlashes($db);
-            $table  = PMA_Util::sqlAddSlashes($table);
-            $query  = "SELECT COUNT(*) ";
-            $query .= "FROM `INFORMATION_SCHEMA`.`TRIGGERS` ";
-            $query .= "WHERE `EVENT_OBJECT_SCHEMA`='$db' ";
-            $query .= "AND `EVENT_OBJECT_TABLE`='$table'";
-            $retval = (int)$GLOBALS['dbi']->fetchValue($query);
+            if (! $GLOBALS['cfg']['Server']['DisableIS']) {
+                $db     = PMA_Util::sqlAddSlashes($db);
+                $table  = PMA_Util::sqlAddSlashes($table);
+                $query  = "SELECT COUNT(*) ";
+                $query .= "FROM `INFORMATION_SCHEMA`.`TRIGGERS` ";
+                $query .= "WHERE `EVENT_OBJECT_SCHEMA` "
+                    . PMA_Util::getCollateForIS() . "='$db' ";
+                $query .= "AND `EVENT_OBJECT_TABLE` "
+                    . PMA_Util::getCollateForIS() . "='$table'";
+                $retval = (int)$GLOBALS['dbi']->fetchValue($query);
+            } else {
+                $db     = PMA_Util::backquote($db);
+                $table  = PMA_Util::sqlAddSlashes($table);
+                $query  = "SHOW TRIGGERS FROM $db WHERE `Table` = '$table'";
+                $retval = (int)$GLOBALS['dbi']->numRows(
+                    $GLOBALS['dbi']->tryQuery($query)
+                );
+            }
             break;
         default:
             break;
@@ -127,44 +166,89 @@ class Node_Table extends Node_DatabaseChild
         $table    = $this->real_name;
         switch ($type) {
         case 'columns':
-            $db     = PMA_Util::sqlAddSlashes($db);
-            $table  = PMA_Util::sqlAddSlashes($table);
-            $query  = "SELECT `COLUMN_NAME` AS `name` ";
-            $query .= "FROM `INFORMATION_SCHEMA`.`COLUMNS` ";
-            $query .= "WHERE `TABLE_NAME`='$table' ";
-            $query .= "AND `TABLE_SCHEMA`='$db' ";
-            $query .= "ORDER BY `COLUMN_NAME` ASC ";
-            $query .= "LIMIT " . intval($pos) . ", $maxItems";
-            $retval = $GLOBALS['dbi']->fetchResult($query);
+            if (! $GLOBALS['cfg']['Server']['DisableIS']) {
+                $db     = PMA_Util::sqlAddSlashes($db);
+                $table  = PMA_Util::sqlAddSlashes($table);
+                $query  = "SELECT `COLUMN_NAME` AS `name` ";
+                $query .= "FROM `INFORMATION_SCHEMA`.`COLUMNS` ";
+                $query .= "WHERE `TABLE_NAME`='$table' ";
+                $query .= "AND `TABLE_SCHEMA`='$db' ";
+                $query .= "ORDER BY `COLUMN_NAME` ASC ";
+                $query .= "LIMIT " . intval($pos) . ", $maxItems";
+                $retval = $GLOBALS['dbi']->fetchResult($query);
+                break;
+            }
+
+            $db     = PMA_Util::backquote($db);
+            $table  = PMA_Util::backquote($table);
+            $query  = "SHOW COLUMNS FROM $table FROM $db";
+            $handle = $GLOBALS['dbi']->tryQuery($query);
+            if ($handle === false) {
+                break;
+            }
+
+            $count = 0;
+            while ($arr = $GLOBALS['dbi']->fetchArray($handle)) {
+                if ($pos <= 0 && $count < $maxItems) {
+                    $retval[] = $arr['Field'];
+                    $count++;
+                }
+                $pos--;
+            }
             break;
         case 'indexes':
             $db     = PMA_Util::backquote($db);
             $table  = PMA_Util::backquote($table);
             $query  = "SHOW INDEXES FROM $table FROM $db";
             $handle = $GLOBALS['dbi']->tryQuery($query);
-            if ($handle !== false) {
-                $count = 0;
-                while ($arr = $GLOBALS['dbi']->fetchArray($handle)) {
-                    if (! in_array($arr['Key_name'], $retval)) {
-                        if ($pos <= 0 && $count < $maxItems) {
-                            $retval[] = $arr['Key_name'];
-                            $count++;
-                        }
-                        $pos--;
-                    }
+            if ($handle === false) {
+                break;
+            }
+
+            $count = 0;
+            while ($arr = $GLOBALS['dbi']->fetchArray($handle)) {
+                if (in_array($arr['Key_name'], $retval)) {
+                    continue;
                 }
+                if ($pos <= 0 && $count < $maxItems) {
+                    $retval[] = $arr['Key_name'];
+                    $count++;
+                }
+                $pos--;
             }
             break;
         case 'triggers':
-            $db     = PMA_Util::sqlAddSlashes($db);
+            if (! $GLOBALS['cfg']['Server']['DisableIS']) {
+                $db     = PMA_Util::sqlAddSlashes($db);
+                $table  = PMA_Util::sqlAddSlashes($table);
+                $query  = "SELECT `TRIGGER_NAME` AS `name` ";
+                $query .= "FROM `INFORMATION_SCHEMA`.`TRIGGERS` ";
+                $query .= "WHERE `EVENT_OBJECT_SCHEMA` "
+                    . PMA_Util::getCollateForIS() . "='$db' ";
+                $query .= "AND `EVENT_OBJECT_TABLE` "
+                    . PMA_Util::getCollateForIS() . "='$table' ";
+                $query .= "ORDER BY `TRIGGER_NAME` ASC ";
+                $query .= "LIMIT " . intval($pos) . ", $maxItems";
+                $retval = $GLOBALS['dbi']->fetchResult($query);
+                break;
+            }
+
+            $db     = PMA_Util::backquote($db);
             $table  = PMA_Util::sqlAddSlashes($table);
-            $query  = "SELECT `TRIGGER_NAME` AS `name` ";
-            $query .= "FROM `INFORMATION_SCHEMA`.`TRIGGERS` ";
-            $query .= "WHERE `EVENT_OBJECT_SCHEMA`='$db' ";
-            $query .= "AND `EVENT_OBJECT_TABLE`='$table' ";
-            $query .= "ORDER BY `TRIGGER_NAME` ASC ";
-            $query .= "LIMIT " . intval($pos) . ", $maxItems";
-            $retval = $GLOBALS['dbi']->fetchResult($query);
+            $query  = "SHOW TRIGGERS FROM $db WHERE `Table` = '$table'";
+            $handle = $GLOBALS['dbi']->tryQuery($query);
+            if ($handle === false) {
+                break;
+            }
+
+            $count = 0;
+            while ($arr = $GLOBALS['dbi']->fetchArray($handle)) {
+                if ($pos <= 0 && $count < $maxItems) {
+                    $retval[] = $arr['Trigger'];
+                    $count++;
+                }
+                $pos--;
+            }
             break;
         default:
             break;
