@@ -21,7 +21,7 @@ if (! defined('PHPMYADMIN')) {
 function PMA_getHtmlForDatabaseComment($db)
 {
     $html_output = '<div class="operations_half_width">'
-        . '<form method="post" action="db_operations.php">'
+        . '<form method="post" action="db_operations.php" id="formDatabaseComment">'
         . PMA_URL_getHiddenInputs($db)
         . '<fieldset>'
         . '<legend>';
@@ -29,7 +29,7 @@ function PMA_getHtmlForDatabaseComment($db)
         $html_output .= '<img class="icon ic_b_comment" '
             . 'src="themes/dot.gif" alt="" />';
     }
-    $html_output .=  __('Database comment: ');
+    $html_output .=  __('Database comment:');
     $html_output .= '</legend>';
     $html_output .= '<input type="text" name="comment" '
         . 'class="textfield" size="30"'
@@ -57,11 +57,11 @@ function PMA_getHtmlForRenameDatabase($db)
         . '<form id="rename_db_form" '
         . 'class="ajax" '
         . 'method="post" action="db_operations.php" '
-        . 'onsubmit="return emptyFormElements(this, \'newname\')">';
+        . 'onsubmit="return emptyCheckTheField(this, \'newname\')">';
     if (isset($_REQUEST['db_collation'])) {
         $html_output .= '<input type="hidden" name="db_collation" '
             . 'value="' . $_REQUEST['db_collation']
-            .'" />' . "\n";
+            . '" />' . "\n";
     }
     $html_output .= '<input type="hidden" name="what" value="data" />'
         . '<input type="hidden" name="db_rename" value="true" />'
@@ -76,7 +76,7 @@ function PMA_getHtmlForRenameDatabase($db)
         . '</legend>';
 
     $html_output .= '<input id="new_db_name" type="text" name="newname" '
-        . 'size="30" class="textfield" value="" />'
+        . 'size="30" class="textfield" value="" required="required" />'
         . '</fieldset>'
         . '<fieldset class="tblFooters">'
         . '<input id="rename_db_input" type="submit" value="' . __('Go') . '" />'
@@ -157,12 +157,12 @@ function PMA_getHtmlForCopyDatabase($db)
     $html_output = '<div class="operations_half_width clearfloat">';
     $html_output .= '<form id="copy_db_form" '
         . 'class="ajax" '
-        . 'method="post" action="db_operations.php"'
-        . 'onsubmit="return emptyFormElements(this, \'newname\')">';
+        . 'method="post" action="db_operations.php" '
+        . 'onsubmit="return emptyCheckTheField(this, \'newname\')">';
 
     if (isset($_REQUEST['db_collation'])) {
         $html_output .= '<input type="hidden" name="db_collation" '
-        . 'value="' . $_REQUEST['db_collation'] .'" />' . "\n";
+        . 'value="' . $_REQUEST['db_collation'] . '" />' . "\n";
     }
     $html_output .= '<input type="hidden" name="db_copy" value="true" />' . "\n"
         . PMA_URL_getHiddenInputs($db);
@@ -175,7 +175,7 @@ function PMA_getHtmlForCopyDatabase($db)
     $html_output .= __('Copy database to:')
         . '</legend>'
         . '<input type="text" name="newname" size="30" '
-        . 'class="textfield" value="" /><br />'
+        . 'class="textfield" value="" required="required" /><br />'
         . PMA_Util::getRadioFields(
             'what', $choices, 'data', true
         );
@@ -219,7 +219,7 @@ function PMA_getHtmlForCopyDatabase($db)
  * Get HTML snippet for change database charset
  *
  * @param string $db    database name
- * @param string $table tabel name
+ * @param string $table table name
  *
  * @return string $html_output
  */
@@ -245,8 +245,7 @@ function PMA_getHtmlForChangeDatabaseCharset($db, $table)
             'db_collation',
             'select_db_collation',
             isset($_REQUEST['db_collation']) ? $_REQUEST['db_collation'] : '',
-            false,
-            3
+            false
         )
         . '</fieldset>'
         . '<fieldset class="tblFooters">'
@@ -258,29 +257,6 @@ function PMA_getHtmlForChangeDatabaseCharset($db, $table)
     return $html_output;
 }
 
-/**
- * Get HTML snippet for export relational schema view
- *
- * @param string $url_query Query string for link
- *
- * @return string $html_output
- */
-function PMA_getHtmlForExportRelationalSchemaView($url_query)
-{
-    $html_output = '<div class="operations_full_width">'
-        . '<fieldset><a href="schema_edit.php?' . $url_query . '">';
-    if (PMA_Util::showIcons('ActionLinksMode')) {
-        $html_output .= PMA_Util::getImage(
-            'b_edit.png'
-        );
-    }
-    $html_output .= __('Edit or export relational schema')
-        . '</a></fieldset>'
-        . '</div>';
-
-    return $html_output;
-}
-
 /**
  * Run the Procedure definitions and function definitions
  *
@@ -332,11 +308,11 @@ function PMA_getSqlQueryAndCreateDbBeforeCopy()
 {
     // lower_case_table_names=1 `DB` becomes `db`
     if (! PMA_DRIZZLE) {
-        $lower_case_table_names = $GLOBALS['dbi']->fetchValue(
+        $lowerCaseTableNames = $GLOBALS['dbi']->fetchValue(
             'SHOW VARIABLES LIKE "lower_case_table_names"', 0, 1
         );
-        if ($lower_case_table_names === '1') {
-            $_REQUEST['newname'] = $GLOBALS['PMA_String']->strtolower(
+        if ($lowerCaseTableNames === '1') {
+            $_REQUEST['newname'] = /*overload*/mb_strtolower(
                 $_REQUEST['newname']
             );
         }
@@ -373,10 +349,10 @@ function PMA_getSqlQueryAndCreateDbBeforeCopy()
  * remove all foreign key constraints and return
  * sql constraints query for full database
  *
- * @param array   $tables_full       array of all tables in given db or dbs
- * @param object  $export_sql_plugin export plugin instance
- * @param boolean $move              whether database name is empty or not
- * @param string  $db                database name
+ * @param array     $tables_full       array of all tables in given db or dbs
+ * @param ExportSql $export_sql_plugin export plugin instance
+ * @param boolean   $move              whether database name is empty or not
+ * @param string    $db                database name
  *
  * @return string sql constraints query for full databases
  */
@@ -390,7 +366,7 @@ function PMA_getSqlConstraintsQueryForFullDb(
         $sql_constraints = '';
         $sql_drop_foreign_keys = '';
         $export_sql_plugin->getTableDef(
-            $db, $each_table, "\n", '', false, false
+            $db, $each_table, "\n", '', false, false, false, false
         );
         if ($move && ! empty($sql_drop_foreign_keys)) {
             $GLOBALS['dbi']->query($sql_drop_foreign_keys);
@@ -406,9 +382,9 @@ function PMA_getSqlConstraintsQueryForFullDb(
 /**
  * Get views as an array and create SQL view stand-in
  *
- * @param array  $tables_full       array of all tables in given db or dbs
- * @param object $export_sql_plugin export plugin instance
- * @param string $db                database name
+ * @param array     $tables_full       array of all tables in given db or dbs
+ * @param ExportSql $export_sql_plugin export plugin instance
+ * @param string    $db                database name
  *
  * @return array $views
  */
@@ -421,6 +397,20 @@ function PMA_getViewsAndCreateSqlViewStandIn(
         // first all the views are collected and a stand-in is created
         // the real views are created after the tables
         if (PMA_Table::isView($db, $each_table)) {
+
+            // If view exists, and 'add drop view' is selected: Drop it!
+            if ($_REQUEST['what'] != 'nocopy'
+                && isset($_REQUEST['drop_if_exists'])
+                && $_REQUEST['drop_if_exists'] == 'true'
+            ) {
+                $drop_query = 'DROP VIEW IF EXISTS '
+                    . PMA_Util::backquote($_REQUEST['newname']) . '.'
+                    . PMA_Util::backquote($each_table);
+                $GLOBALS['dbi']->query($drop_query);
+
+                $GLOBALS['sql_query'] .= "\n" . $drop_query . ';';
+            }
+
             $views[] = $each_table;
             // Create stand-in definition to resolve view dependencies
             $sql_view_standin = $export_sql_plugin->getTableDefStandIn(
@@ -448,7 +438,7 @@ function PMA_getSqlQueryForCopyTable($tables_full, $sql_query, $move, $db)
 {
     $error = false;
     foreach ($tables_full as $each_table => $tmp) {
-        // skip the views; we have creted stand-in definitions
+        // skip the views; we have created stand-in definitions
         if (PMA_Table::isView($db, $each_table)) {
             continue;
         }
@@ -576,7 +566,7 @@ function PMA_handleTheViews($views, $move, $db)
 }
 
 /**
- * Create all accumulated constraaints
+ * Create all accumulated constraints
  *
  * @return void
  */
@@ -665,7 +655,7 @@ function PMA_getHtmlForMoveTable()
     $html_output = '<div class="operations_half_width">';
     $html_output .= '<form method="post" action="tbl_operations.php"'
         . ' id="moveTableForm" class="ajax"'
-        . ' onsubmit="return emptyFormElements(this, \'new_name\')">'
+        . ' onsubmit="return emptyCheckTheField(this, \'new_name\')">'
         . PMA_URL_getHiddenInputs($GLOBALS['db'], $GLOBALS['table']);
 
     $html_output .= '<input type="hidden" name="reload" value="1" />'
@@ -686,7 +676,7 @@ function PMA_getHtmlForMoveTable()
     }
     $html_output .= '&nbsp;<strong>.</strong>&nbsp;';
     $html_output .= '<input class="halfWidth" type="text" size="20" name="new_name"'
-        . ' onfocus="this.select()" required '
+        . ' required="required" '
         . 'value="' . htmlspecialchars($GLOBALS['table']) . '" /><br />';
 
     // starting with MySQL 5.0.24, SHOW CREATE TABLE includes the AUTO_INCREMENT
@@ -789,15 +779,16 @@ function PMA_getTableOptionFieldset($comment, $tbl_collation,
     //Change table name
     $html_output .= '<tr><td>' . __('Rename table to') . '</td>'
         . '<td>'
-        . '<input type="text" size="20" name="new_name" onfocus="this.select()"'
-        . 'value="' . htmlspecialchars($GLOBALS['table']) . '" required />'
+        . '<input type="text" size="20" name="new_name" '
+        . 'value="' . htmlspecialchars($GLOBALS['table'])
+        . '" required="required" />'
         . '</td>'
         . '</tr>';
 
     //Table comments
     $html_output .= '<tr><td>' . __('Table comments') . '</td>'
         . '<td><input type="text" name="comment" maxlength="60" size="30"'
-        . 'value="' . htmlspecialchars($comment) . '" onfocus="this.select()" />'
+        . 'value="' . htmlspecialchars($comment) . '" />'
         . '<input type="hidden" name="prev_comment" value="'
         . htmlspecialchars($comment) . '" />'
         . '</td>'
@@ -819,7 +810,7 @@ function PMA_getTableOptionFieldset($comment, $tbl_collation,
         . '<td>'
         . PMA_generateCharsetDropdownBox(
             PMA_CSDROPDOWN_COLLATION,
-            'tbl_collation', null, $tbl_collation, false, 3
+            'tbl_collation', null, $tbl_collation, false
         )
         . '</td>'
         . '</tr>';
@@ -877,7 +868,7 @@ function PMA_getTableOptionFieldset($comment, $tbl_collation,
         );
     } // end if (ARIA)
 
-    if (strlen($auto_increment) > 0
+    if (/*overload*/mb_strlen($auto_increment) > 0
         && ($is_myisam_or_aria || $is_innodb || $is_pbxt)
     ) {
         $html_output .= '<tr><td>'
@@ -897,7 +888,8 @@ function PMA_getTableOptionFieldset($comment, $tbl_collation,
     // (if the table was compressed, it can be seen on the Structure page)
 
     if (isset($possible_row_formats[$tbl_storage_engine])) {
-        $current_row_format = strtoupper($GLOBALS['showtable']['Row_format']);
+        $current_row_format
+            = /*overload*/mb_strtoupper($GLOBALS['showtable']['Row_format']);
         $html_output .= '<tr><td>'
             . '<label for="new_row_format">ROW_FORMAT</label></td>'
             . '<td>';
@@ -927,8 +919,8 @@ function PMA_getHtmlForTableRow($attribute, $label, $val)
 {
     return '<tr>'
         . '<td><label for="' . $attribute . '">' . $label . '</label></td>'
-        . '<td><input type="checkbox" name="'. $attribute .'"'
-        . ' id="' . $attribute .'"'
+        . '<td><input type="checkbox" name="' . $attribute . '"'
+        . ' id="' . $attribute . '"'
         . ' value="1"'
         . ((!empty($val) && $val == 1) ? ' checked="checked"' : '') . '/></td>'
         . '</tr>';
@@ -969,15 +961,15 @@ function PMA_getPossibleRowFormat()
         )
     );
 
-    $innodb_engine_plugin = PMA_StorageEngine::getEngine('innodb');
-    $innodb_plugin_version = $innodb_engine_plugin->getInnodbPluginVersion();
-    if (!empty($innodb_plugin_version)) {
-        $innodb_file_format = $innodb_engine_plugin->getInnodbFileFormat();
+    $innodbEnginePlugin = PMA_StorageEngine::getEngine('innodb');
+    $innodbPluginVersion = $innodbEnginePlugin->getInnodbPluginVersion();
+    if (!empty($innodbPluginVersion)) {
+        $innodb_file_format = $innodbEnginePlugin->getInnodbFileFormat();
     } else {
         $innodb_file_format = '';
     }
     if ('Barracuda' == $innodb_file_format
-        && $innodb_engine_plugin->supportsFilePerTable()
+        && $innodbEnginePlugin->supportsFilePerTable()
     ) {
         $possible_row_formats['INNODB']['DYNAMIC'] = 'DYNAMIC';
         $possible_row_formats['INNODB']['COMPRESSED'] = 'COMPRESSED';
@@ -998,7 +990,7 @@ function PMA_getHtmlForCopytable()
         . 'name="copyTable" '
         . 'id="copyTable" '
         . ' class="ajax" '
-        . 'onsubmit="return emptyFormElements(this, \'new_name\')">'
+        . 'onsubmit="return emptyCheckTheField(this, \'new_name\')">'
         . PMA_URL_getHiddenInputs($GLOBALS['db'], $GLOBALS['table'])
         . '<input type="hidden" name="reload" value="1" />';
 
@@ -1009,16 +1001,16 @@ function PMA_getHtmlForCopytable()
     if (count($GLOBALS['pma']->databases) > $GLOBALS['cfg']['MaxDbList']) {
         $html_output .= '<input class="halfWidth" type="text" maxlength="100" '
             . 'size="30" name="target_db" '
-            . 'value="'. htmlspecialchars($GLOBALS['db']) . '"/>';
+            . 'value="' . htmlspecialchars($GLOBALS['db']) . '"/>';
     } else {
         $html_output .= '<select class="halfWidth" name="target_db">'
             . $GLOBALS['pma']->databases->getHtmlOptions(true, false)
             . '</select>';
     }
     $html_output .= '&nbsp;<strong>.</strong>&nbsp;';
-    $html_output .= '<input class="halfWidth" type="text" required '
-        . 'size="20" name="new_name" onfocus="this.select()" '
-        . 'value="'. htmlspecialchars($GLOBALS['table']) . '"/><br />';
+    $html_output .= '<input class="halfWidth" type="text" required="required" '
+        . 'size="20" name="new_name" '
+        . 'value="' . htmlspecialchars($GLOBALS['table']) . '"/><br />';
 
     $choices = array(
             'structure' => __('Structure only'),
@@ -1044,7 +1036,7 @@ function PMA_getHtmlForCopytable()
         $html_output .= '<input type="checkbox" name="add_constraints" '
             . 'value="1" id="checkbox_constraints" />';
         $html_output .= '<label for="checkbox_constraints">'
-            .__('Add constraints') . '</label><br />';
+            . __('Add constraints') . '</label><br />';
     } // endif
 
     if (isset($_COOKIE['pma_switch_to_new'])
@@ -1063,7 +1055,7 @@ function PMA_getHtmlForCopytable()
         . '</fieldset>';
 
     $html_output .= '<fieldset class="tblFooters">'
-        . '<input type="submit" name="submit_copy" value="' .__('Go') . '" />'
+        . '<input type="submit" name="submit_copy" value="' . __('Go') . '" />'
         . '</fieldset>'
         . '</form>'
         . '</div>';
@@ -1072,7 +1064,7 @@ function PMA_getHtmlForCopytable()
 }
 
 /**
- * Get HTML snippet for table maintence
+ * Get HTML snippet for table maintenance
  *
  * @param boolean $is_myisam_or_aria whether MYISAM | ARIA or not
  * @param boolean $is_innodb         whether innodb or not
@@ -1140,8 +1132,7 @@ function PMA_getListofMaintainActionLink($is_myisam_or_aria,
                 __('Defragment table'),
                 $params,
                 $url_params,
-                'InnoDB_File_Defragmenting',
-                'Table_types'
+                'InnoDB_File_Defragmenting'
             );
         }
         if ($is_innodb || $is_myisam_or_aria || $is_berkeleydb) {
@@ -1191,7 +1182,7 @@ function PMA_getListofMaintainActionLink($is_myisam_or_aria,
         'sql_query' => 'FLUSH TABLE '
             . PMA_Util::backquote($GLOBALS['table']),
         'message_to_show' => sprintf(
-            __('Table %s has been flushed'),
+            __('Table %s has been flushed.'),
             htmlspecialchars($GLOBALS['table'])
         ),
         'reload' => 1,
@@ -1210,20 +1201,20 @@ function PMA_getListofMaintainActionLink($is_myisam_or_aria,
 /**
  * Get maintain action HTML link
  *
- * @param string $action     action name
- * @param array  $params     url parameters array
- * @param array  $url_params additional url parameters
- * @param string $link       contains name of page/anchor that is being linked
+ * @param string $action_message action message
+ * @param array  $params         url parameters array
+ * @param array  $url_params     additional url parameters
+ * @param string $link           contains name of page/anchor that is being linked
  *
  * @return string $html_output
  */
-function PMA_getMaintainActionlink($action, $params, $url_params, $link)
+function PMA_getMaintainActionlink($action_message, $params, $url_params, $link)
 {
     return '<li>'
         . '<a class="maintain_action ajax" '
         . 'href="sql.php'
-        . PMA_URL_getCommon(array_merge($url_params, $params)) .'">'
-        . $action
+        . PMA_URL_getCommon(array_merge($url_params, $params)) . '">'
+        . $action_message
         . '</a>'
         . PMA_Util::showMySQLDocu($link)
         . '</li>';
@@ -1233,13 +1224,13 @@ function PMA_getMaintainActionlink($action, $params, $url_params, $link)
  * Get HTML for Delete data or table (truncate table, drop table)
  *
  * @param array $truncate_table_url_params url parameter array for truncate table
- * @param array $drop_table_url_params     url parameter array for drop table
+ * @param array $dropTableUrlParams        url parameter array for drop table
  *
  * @return string $html_output
  */
 function PMA_getHtmlForDeleteDataOrTable(
     $truncate_table_url_params,
-    $drop_table_url_params
+    $dropTableUrlParams
 ) {
     $html_output = '<div class="operations_half_width">'
         . '<fieldset class="caution">'
@@ -1255,9 +1246,9 @@ function PMA_getHtmlForDeleteDataOrTable(
             'truncate_tbl_anchor'
         );
     }
-    if (!empty ($drop_table_url_params)) {
+    if (!empty ($dropTableUrlParams)) {
         $html_output .= PMA_getDeleteDataOrTablelink(
-            $drop_table_url_params,
+            $dropTableUrlParams,
             'DROP_TABLE',
             __('Delete the table (DROP)'),
             'drop_tbl_anchor'
@@ -1274,15 +1265,15 @@ function PMA_getHtmlForDeleteDataOrTable(
  * @param array  $url_params url parameter array for delete data or table
  * @param string $syntax     TRUNCATE_TABLE or DROP_TABLE or DROP_DATABASE
  * @param string $link       link to be shown
- * @param string $id         id of the link
+ * @param string $htmlId     id of the link
  *
  * @return String html output
  */
-function PMA_getDeleteDataOrTablelink($url_params, $syntax, $link, $id)
+function PMA_getDeleteDataOrTablelink($url_params, $syntax, $link, $htmlId)
 {
     return  '<li><a '
         . 'href="sql.php' . PMA_URL_getCommon($url_params) . '"'
-        . ' id="' . $id . '" class="ajax">'
+        . ' id="' . $htmlId . '" class="ajax">'
         . $link . '</a>'
         . PMA_Util::showMySQLDocu($syntax)
         . '</li>';
@@ -1439,25 +1430,25 @@ function PMA_getQueryAndResultForReorderingTable()
 /**
  * Get table alters array
  *
- * @param boolean $is_myisam_or_aria      whether MYISAM | ARIA or not
- * @param boolean $is_isam                whether ISAM or not
- * @param string  $pack_keys              pack keys
- * @param string  $checksum               value of checksum
- * @param boolean $is_aria                whether ARIA or not
- * @param string  $page_checksum          value of page checksum
- * @param string  $delay_key_write        delay key write
- * @param boolean $is_innodb              whether INNODB or not
- * @param boolean $is_pbxt                whether PBXT or not
- * @param string  $row_format             row format
- * @param string  $new_tbl_storage_engine table storage engine
- * @param string  $transactional          value of transactional
- * @param string  $tbl_collation          collation of the table
+ * @param boolean $is_myisam_or_aria   whether MYISAM | ARIA or not
+ * @param boolean $is_isam             whether ISAM or not
+ * @param string  $pack_keys           pack keys
+ * @param string  $checksum            value of checksum
+ * @param boolean $is_aria             whether ARIA or not
+ * @param string  $page_checksum       value of page checksum
+ * @param string  $delay_key_write     delay key write
+ * @param boolean $is_innodb           whether INNODB or not
+ * @param boolean $is_pbxt             whether PBXT or not
+ * @param string  $row_format          row format
+ * @param string  $newTblStorageEngine table storage engine
+ * @param string  $transactional       value of transactional
+ * @param string  $tbl_collation       collation of the table
  *
  * @return array  $table_alters
  */
 function PMA_getTableAltersArray($is_myisam_or_aria, $is_isam, $pack_keys,
     $checksum, $is_aria, $page_checksum, $delay_key_write, $is_innodb,
-    $is_pbxt, $row_format, $new_tbl_storage_engine, $transactional, $tbl_collation
+    $is_pbxt, $row_format, $newTblStorageEngine, $transactional, $tbl_collation
 ) {
     global $auto_increment;
 
@@ -1469,10 +1460,11 @@ function PMA_getTableAltersArray($is_myisam_or_aria, $is_isam, $pack_keys,
         $table_alters[] = 'COMMENT = \''
             . PMA_Util::sqlAddSlashes($_REQUEST['comment']) . '\'';
     }
-    if (! empty($new_tbl_storage_engine)
-        && strtolower($new_tbl_storage_engine) !== strtolower($GLOBALS['tbl_storage_engine'])
+
+    if (! empty($newTblStorageEngine)
+        && /*overload*/mb_strtolower($newTblStorageEngine) !== /*overload*/mb_strtolower($GLOBALS['tbl_storage_engine'])
     ) {
-        $table_alters[] = 'ENGINE = ' . $new_tbl_storage_engine;
+        $table_alters[] = 'ENGINE = ' . $newTblStorageEngine;
     }
     if (! empty($_REQUEST['tbl_collation'])
         && $_REQUEST['tbl_collation'] !== $tbl_collation
@@ -1528,13 +1520,14 @@ function PMA_getTableAltersArray($is_myisam_or_aria, $is_isam, $pack_keys,
             . PMA_Util::sqlAddSlashes($_REQUEST['new_auto_increment']);
     }
 
+    $newRowFormat = $_REQUEST['new_row_format'];
+    $newRowFormatLower = /*overload*/mb_strtolower($newRowFormat);
     if (($is_myisam_or_aria || $is_innodb || $is_pbxt)
-        &&  ! empty($_REQUEST['new_row_format'])
-        && (!strlen($row_format)
-        || strtolower($_REQUEST['new_row_format']) !== strtolower($row_format))
+        &&  ! empty($newRowFormat)
+        && (!/*overload*/mb_strlen($row_format)
+        || $newRowFormatLower !== /*overload*/mb_strtolower($row_format))
     ) {
-        $table_alters[] = 'ROW_FORMAT = '
-            . PMA_Util::sqlAddSlashes($_REQUEST['new_row_format']);
+        $table_alters[] = 'ROW_FORMAT = ' . PMA_Util::sqlAddSlashes($newRowFormat);
     }
 
     return $table_alters;
@@ -1550,21 +1543,19 @@ function PMA_getTableAltersArray($is_myisam_or_aria, $is_isam, $pack_keys,
  */
 function PMA_setGlobalVariablesForEngine($tbl_storage_engine)
 {
-    $is_myisam_or_aria = $is_isam = $is_innodb = $is_berkeleydb
-        = $is_aria = $is_pbxt = false;
-    $upper_tbl_storage_engine = strtoupper($tbl_storage_engine);
+    $upperTblStorEngine = /*overload*/mb_strtoupper($tbl_storage_engine);
 
     //Options that apply to MYISAM usually apply to ARIA
-    $is_myisam_or_aria = ($upper_tbl_storage_engine == 'MYISAM'
-        || $upper_tbl_storage_engine == 'ARIA'
-        || $upper_tbl_storage_engine == 'MARIA'
+    $is_myisam_or_aria = ($upperTblStorEngine == 'MYISAM'
+        || $upperTblStorEngine == 'ARIA'
+        || $upperTblStorEngine == 'MARIA'
     );
-    $is_aria = ($upper_tbl_storage_engine == 'ARIA');
+    $is_aria = ($upperTblStorEngine == 'ARIA');
 
-    $is_isam = ($upper_tbl_storage_engine == 'ISAM');
-    $is_innodb = ($upper_tbl_storage_engine == 'INNODB');
-    $is_berkeleydb = ($upper_tbl_storage_engine == 'BERKELEYDB');
-    $is_pbxt = ($upper_tbl_storage_engine == 'PBXT');
+    $is_isam = ($upperTblStorEngine == 'ISAM');
+    $is_innodb = ($upperTblStorEngine == 'INNODB');
+    $is_berkeleydb = ($upperTblStorEngine == 'BERKELEYDB');
+    $is_pbxt = ($upperTblStorEngine == 'PBXT');
 
     return array(
         $is_myisam_or_aria, $is_innodb, $is_isam,
@@ -1616,4 +1607,84 @@ function PMA_getQueryAndResultForPartition()
     return array($sql_query, $result);
 }
 
+
+/**
+ * Move or copy a table
+ *
+ * @param string $db    current database name
+ * @param string $table current table name
+ *
+ * @return void
+ */
+function PMA_moveOrCopyTable($db, $table)
+{
+    /**
+     * Selects the database to work with
+     */
+    $GLOBALS['dbi']->selectDb($db);
+
+    /**
+     * $_REQUEST['target_db'] could be empty in case we came from an input field
+     * (when there are many databases, no drop-down)
+     */
+    if (empty($_REQUEST['target_db'])) {
+        $_REQUEST['target_db'] = $db;
+    }
+
+    /**
+     * A target table name has been sent to this script -> do the work
+     */
+    if (PMA_isValid($_REQUEST['new_name'])) {
+        if ($db == $_REQUEST['target_db'] && $table == $_REQUEST['new_name']) {
+            if (isset($_REQUEST['submit_move'])) {
+                $message = PMA_Message::error(__('Can\'t move table to same one!'));
+            } else {
+                $message = PMA_Message::error(__('Can\'t copy table to same one!'));
+            }
+        } else {
+            PMA_Table::moveCopy(
+                $db, $table, $_REQUEST['target_db'], $_REQUEST['new_name'],
+                $_REQUEST['what'], isset($_REQUEST['submit_move']), 'one_table'
+            );
+
+            if (isset($_REQUEST['submit_move'])) {
+                $message = PMA_Message::success(
+                    __('Table %s has been moved to %s.')
+                );
+            } else {
+                $message = PMA_Message::success(
+                    __('Table %s has been copied to %s.')
+                );
+            }
+            $old = PMA_Util::backquote($db) . '.'
+                . PMA_Util::backquote($table);
+            $message->addParam($old);
+            $new = PMA_Util::backquote($_REQUEST['target_db']) . '.'
+                . PMA_Util::backquote($_REQUEST['new_name']);
+            $message->addParam($new);
+
+            /* Check: Work on new table or on old table? */
+            if (isset($_REQUEST['submit_move'])
+                || PMA_isValid($_REQUEST['switch_to_new'])
+            ) {
+            }
+        }
+    } else {
+        /**
+         * No new name for the table!
+         */
+        $message = PMA_Message::error(__('The table name is empty!'));
+    }
+
+    if ($GLOBALS['is_ajax_request'] == true) {
+        $response = PMA_Response::getInstance();
+        $response->addJSON('message', $message);
+        if ($message->isSuccess()) {
+            $response->addJSON('db', $GLOBALS['db']);
+        } else {
+            $response->isSuccess(false);
+        }
+        exit;
+    }
+}
 ?>
