@@ -18,7 +18,9 @@ if (! defined('PHPMYADMIN')) {
  */
 function PMA_languageName($tmplang)
 {
-    $lang_name = ucfirst(substr(strrchr($tmplang[0], '|'), 1));
+    $lang_name = ucfirst(
+        /*overload*/mb_substr(/*overload*/mb_strrchr($tmplang[0], '|'), 1)
+    );
 
     // Include native name if non empty
     if (!empty($tmplang[2])) {
@@ -84,7 +86,9 @@ function PMA_langCheck()
     // try to find out user's language by checking its HTTP_ACCEPT_LANGUAGE variable;
     // prevent XSS
     $accepted_languages = PMA_getenv('HTTP_ACCEPT_LANGUAGE');
-    if ($accepted_languages && false === strpos($accepted_languages, '<')) {
+    if ($accepted_languages
+        && false === /*overload*/mb_strpos($accepted_languages, '<')
+    ) {
         foreach (explode(',', $accepted_languages) as $lang) {
             if (PMA_langDetect($lang, 1)) {
                 return true;
@@ -153,11 +157,14 @@ function PMA_langDetect($str, $envType)
         // $envType =  1 for the 'HTTP_ACCEPT_LANGUAGE' environment variable,
         //             2 for the 'HTTP_USER_AGENT' one
         $expr = $value[0];
-        if (strpos($expr, '[-_]') === false) {
+        if (/*overload*/mb_strpos($expr, '[-_]') === false) {
             $expr = str_replace('|', '([-_][[:alpha:]]{2,3})?|', $expr);
         }
-        if (($envType == 1 && preg_match('/^(' . addcslashes($expr, '/') . ')(;q=[0-9]\\.[0-9])?$/i', $str))
-            || ($envType == 2 && preg_match('/(\(|\[|;[[:space:]])(' . addcslashes($expr, '/') . ')(;|\]|\))/i', $str))
+        $pattern1 = '/^(' . addcslashes($expr, '/') . ')(;q=[0-9]\\.[0-9])?$/i';
+        $pattern2 = '/(\(|\[|;[[:space:]])(' . addcslashes($expr, '/')
+            . ')(;|\]|\))/i';
+        if (($envType == 1 && preg_match($pattern1, $str))
+            || ($envType == 2 && preg_match($pattern2, $str))
         ) {
             if (PMA_langSet($lang)) {
                 return true;
@@ -203,17 +210,29 @@ function PMA_langDetails($lang)
     case 'af':
         return array('af|afrikaans', 'af', '');
     case 'ar':
-        return array('ar|arabic', 'ar', '&#1575;&#1604;&#1593;&#1585;&#1576;&#1610;&#1577;');
+        return array(
+            'ar|arabic',
+            'ar',
+            '&#1575;&#1604;&#1593;&#1585;&#1576;&#1610;&#1577;'
+        );
     case 'az':
         return array('az|azerbaijani', 'az', 'Az&#601;rbaycanca');
     case 'bn':
         return array('bn|bangla', 'bn', 'বাংলা');
     case 'be':
-        return array('be|belarusian', 'be', '&#1041;&#1077;&#1083;&#1072;&#1088;&#1091;&#1089;&#1082;&#1072;&#1103;');
+        return array(
+            'be|belarusian',
+            'be',
+            '&#1041;&#1077;&#1083;&#1072;&#1088;&#1091;&#1089;&#1082;&#1072;&#1103;'
+        );
     case 'be@latin':
         return array('be[-_]lat|belarusian latin', 'be-lat', 'Bie&#0322;aruskaja');
     case 'bg':
-        return array('bg|bulgarian', 'bg', '&#1041;&#1098;&#1083;&#1075;&#1072;&#1088;&#1089;&#1082;&#1080;');
+        return array(
+            'bg|bulgarian',
+            'bg',
+            '&#1041;&#1098;&#1083;&#1075;&#1072;&#1088;&#1089;&#1082;&#1080;'
+        );
     case 'bs':
         return array('bs|bosnian', 'bs', 'Bosanski');
     case 'br':
@@ -231,7 +250,11 @@ function PMA_langDetails($lang)
     case 'de':
         return array('de|german', 'de', 'Deutsch');
     case 'el':
-        return array('el|greek', 'el', '&Epsilon;&lambda;&lambda;&eta;&nu;&iota;&kappa;&#940;');
+        return array(
+            'el|greek',
+            'el',
+            '&Epsilon;&lambda;&lambda;&eta;&nu;&iota;&kappa;&#940;'
+        );
     case 'en':
         return array('en|english', 'en', '');
     case 'en_GB':
@@ -271,11 +294,19 @@ function PMA_langDetails($lang)
     case 'ko':
         return array('ko|korean', 'ko', '&#54620;&#44397;&#50612;');
     case 'ka':
-        return array('ka|georgian', 'ka', '&#4325;&#4304;&#4320;&#4311;&#4323;&#4314;&#4312;');
+        return array(
+            'ka|georgian',
+            'ka',
+            '&#4325;&#4304;&#4320;&#4311;&#4323;&#4314;&#4312;'
+        );
     case 'kk':
         return array('kk|kazakh', 'kk', 'Қазақ');
+    case 'km':
+        return array('km|khmer', 'km', 'ខ្មែរ');
     case 'kn':
         return array('kn|kannada', 'kn', 'ಕನ್ನಡ');
+    case 'ksh':
+        return array('ksh|colognian', 'ksh', 'Kölsch');
     case 'ky':
         return array('ky|kyrgyz', 'ky', 'Кыргызча');
     case 'lt':
@@ -287,9 +318,15 @@ function PMA_langDetails($lang)
     case 'ml':
         return array('ml|malayalam', 'ml', 'Malayalam');
     case 'mn':
-        return array('mn|mongolian', 'mn', '&#1052;&#1086;&#1085;&#1075;&#1086;&#1083;');
+        return array(
+            'mn|mongolian',
+            'mn',
+            '&#1052;&#1086;&#1085;&#1075;&#1086;&#1083;'
+        );
     case 'ms':
         return array('ms|malay', 'ms', 'Bahasa Melayu');
+    case 'ne':
+        return array('ne|nepali', 'ne', 'नेपाली');
     case 'nl':
         return array('nl|dutch', 'nl', 'Nederlands');
     case 'nb':
@@ -305,7 +342,11 @@ function PMA_langDetails($lang)
     case 'ro':
         return array('ro|romanian', 'ro', 'Rom&acirc;n&#259;');
     case 'ru':
-        return array('ru|russian', 'ru', '&#1056;&#1091;&#1089;&#1089;&#1082;&#1080;&#1081;');
+        return array(
+            'ru|russian',
+            'ru',
+            '&#1056;&#1091;&#1089;&#1089;&#1082;&#1080;&#1081;'
+        );
     case 'si':
         return array('si|sinhala', 'si', '&#3523;&#3538;&#3458;&#3524;&#3517;');
     case 'sk':
@@ -317,7 +358,11 @@ function PMA_langDetails($lang)
     case 'sr@latin':
         return array('sr[-_]lat|serbian latin', 'sr-lat', 'Srpski');
     case 'sr':
-        return array('sr|serbian', 'sr', '&#1057;&#1088;&#1087;&#1089;&#1082;&#1080;');
+        return array(
+            'sr|serbian',
+            'sr',
+            '&#1057;&#1088;&#1087;&#1089;&#1082;&#1080;'
+        );
     case 'sv':
         return array('sv|swedish', 'sv', 'Svenska');
     case 'ta':
@@ -325,7 +370,11 @@ function PMA_langDetails($lang)
     case 'te':
         return array('te|telugu', 'te', 'తెలుగు');
     case 'th':
-        return array('th|thai', 'th', '&#3616;&#3634;&#3625;&#3634;&#3652;&#3607;&#3618;');
+        return array(
+            'th|thai',
+            'th',
+            '&#3616;&#3634;&#3625;&#3634;&#3652;&#3607;&#3618;'
+        );
     case 'tk':
         return array('tk|turkmen', 'tk', 'türkmençe');
     case 'tr':
@@ -335,17 +384,31 @@ function PMA_langDetails($lang)
     case 'ug':
         return array('ug|uyghur', 'ug', 'ئۇيغۇرچە');
     case 'uk':
-        return array('uk|ukrainian', 'uk', '&#1059;&#1082;&#1088;&#1072;&#1111;&#1085;&#1089;&#1100;&#1082;&#1072;');
+        return array(
+            'uk|ukrainian',
+            'uk',
+            '&#1059;&#1082;&#1088;&#1072;&#1111;&#1085;&#1089;&#1100;&#1082;&#1072;'
+        );
     case 'ur':
         return array('ur|urdu', 'ur', 'اُردوُ');
     case 'uz@latin':
         return array('uz[-_]lat|uzbek-latin', 'uz-lat', 'O&lsquo;zbekcha');
     case 'uz':
-        return array('uz[-_]cyr|uzbek-cyrillic', 'uz-cyr', '&#1038;&#1079;&#1073;&#1077;&#1082;&#1095;&#1072;');
+        return array(
+            'uz[-_]cyr|uzbek-cyrillic',
+            'uz-cyr',
+            '&#1038;&#1079;&#1073;&#1077;&#1082;&#1095;&#1072;'
+        );
+    case 'vi':
+        return array('vi|vietnamese', 'vi', 'Tiếng Việt');
     case 'vls':
         return array('vls|flemish', 'vls', 'West-Vlams');
     case 'zh_TW':
-        return array('zh[-_](tw|hk)|chinese traditional', 'zh-TW', '&#20013;&#25991;');
+        return array(
+            'zh[-_](tw|hk)|chinese traditional',
+            'zh-TW',
+            '&#20013;&#25991;'
+        );
     case 'zh_CN':
         // only TW and HK use traditional Chinese while others (CN, SG, MY)
         // use simplified Chinese
@@ -382,9 +445,10 @@ function PMA_langList()
 
     /* Process all files */
     while (false !== ($file = readdir($handle))) {
+        $path = $GLOBALS['lang_path'] . '/' . $file . '/LC_MESSAGES/phpmyadmin.mo';
         if ($file != "."
             && $file != ".."
-            && file_exists($GLOBALS['lang_path'] . '/' . $file . '/LC_MESSAGES/phpmyadmin.mo')
+            && file_exists($path)
         ) {
             $result[$file] = PMA_langDetails($file);
         }
@@ -536,34 +600,14 @@ $GLOBALS['l']['w_page'] = __('Page number:');
 
 
 // now, that we have loaded the language strings we can send the errors
-if ($GLOBALS['lang_failed_cfg']) {
+if ($GLOBALS['lang_failed_cfg']
+    || $GLOBALS['lang_failed_cookie']
+    || $GLOBALS['lang_failed_request']) {
     trigger_error(
-        sprintf(
-            __('Unknown language: %1$s.'),
-            htmlspecialchars($GLOBALS['lang_failed_cfg'])
-        ),
+        __('Ignoring unsupported language code.'),
         E_USER_ERROR
     );
 }
-if ($GLOBALS['lang_failed_cookie']) {
-    trigger_error(
-        sprintf(
-            __('Unknown language: %1$s.'),
-            htmlspecialchars($GLOBALS['lang_failed_cookie'])
-        ),
-        E_USER_ERROR
-    );
-}
-if ($GLOBALS['lang_failed_request']) {
-    trigger_error(
-        sprintf(
-            __('Unknown language: %1$s.'),
-            htmlspecialchars($GLOBALS['lang_failed_request'])
-        ),
-        E_USER_ERROR
-    );
-}
-
 unset(
     $line, $fall_back_lang, $GLOBALS['lang_failed_cfg'],
     $GLOBALS['lang_failed_cookie'], $GLOBALS['lang_failed_request']
