@@ -78,7 +78,7 @@ function PMA_getAjaxReturnForSetVal($variable_doc_links)
         );
         $value = floatval($matches[1]) * PMA_Util::pow(
             1024,
-            $exp[strtolower($matches[3])]
+            $exp[/*overload*/mb_strtolower($matches[3])]
         );
     } else {
         $value = PMA_Util::sqlAddSlashes($value);
@@ -149,7 +149,7 @@ function PMA_formatVariable($name, $value, $variable_doc_links)
  */
 function PMA_getHtmlForLinkTemplates()
 {
-    $url = 'server_variables.php' . PMA_URL_getCommon(array());
+    $url = 'server_variables.php' . PMA_URL_getCommon();
     $output  = '<a style="display: none;" href="#" class="editLink">';
     $output .= PMA_Util::getIcon('b_edit.png', __('Edit')) . '</a>';
     $output .= '<a style="display: none;" href="'
@@ -1680,5 +1680,3 @@ function PMA_getArrayForDocumentLinks()
 }
 
 ?>
-
-
