@@ -2,7 +2,7 @@
 /* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
  * File for vendor customisation, you can change here paths or some behaviour,
- * which vendors such as Linux distibutions might want to change.
+ * which vendors such as Linux distributions might want to change.
  *
  * For changing this file you should know what you are doing. For this reason
  * options here are not part of normal configuration.
@@ -36,6 +36,12 @@ define('SETUP_CONFIG_FILE', './config/config.inc.php');
  */
 define('SETUP_DIR_WRITABLE', true);
 
+/**
+ * Directory where examples reside. Useful when you want to include
+ * the examples directory with documentation, eg. /usr/share/doc.
+ */
+define('EXAMPLES_DIR', './examples/');
+
 /**
  * Directory where configuration files are stored.
  * It is not used directly in code, just a convenient
@@ -74,6 +80,11 @@ define('GETTEXT_INC', './libraries/php-gettext/gettext.inc');
  */
 define('TCPDF_INC', './libraries/tcpdf/tcpdf.php');
 
+/**
+ * Path to the phpseclib. Useful when you want to use system phpseclib.
+ */
+define('PHPSECLIB_INC_DIR', './libraries/phpseclib/');
+
 /**
  * Avoid referring to nonexistent files (causes warnings when open_basedir
  * is used)
